<?php
/*
Plugin Name: Cascara Core
Plugin URI: https://victorthemes.com/wp-themes
Description: Plugin to contain shortcodes and custom post types of the cascara theme.
Author: VictorThemes
Author URI: https://victorthemes.com/wp-themes/cascara
Version: 1.8
Text Domain: cascara-core
*/

if( ! function_exists( 'cascara_block_direct_access' ) ) {
	function cascara_block_direct_access() {
		if( ! defined( 'ABSPATH' ) ) {
			exit( 'Forbidden' );
		}
	}
}

// Plugin URL
define( 'CASCARA_PLUGIN_URL', plugins_url( '/', __FILE__ ) );

// Plugin PATH
define( 'CASCARA_PLUGIN_PATH', plugin_dir_path( __FILE__ ) );
define( 'CASCARA_PLUGIN_ASTS', CASCARA_PLUGIN_URL . 'assets' );
define( 'CASCARA_PLUGIN_IMGS', CASCARA_PLUGIN_ASTS . '/images' );
define( 'CASCARA_PLUGIN_INC', CASCARA_PLUGIN_PATH . 'inc' );

// DIRECTORY SEPARATOR
define ( 'DS' , DIRECTORY_SEPARATOR );

// Cascara Shortcode Path
define( 'CASCARA_SHORTCODE_BASE_PATH', CASCARA_PLUGIN_PATH . 'visual-composer/' );
define( 'CASCARA_SHORTCODE_PATH', CASCARA_SHORTCODE_BASE_PATH . 'shortcodes/' );

/**
 * Check if Codestar Framework is Active or Not!
 */
function cascara_framework_active() {
  return ( defined( 'CS_VERSION' ) ) ? true : false;
}

/* VTHEME_NAME_P */
define('VTHEME_NAME_P', 'Cascara');

// Initial File
include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
if (is_plugin_active('cascara-core/cascara-core.php')) {

	// Custom Post Type
	require_once( CASCARA_PLUGIN_INC . '/custom-post-type.php' );

  if (!defined( 'CS_VERSION' )) {
    require_once( CASCARA_PLUGIN_INC . '/theme-metabox.php' );
  }

  // Shortcodes
  require_once( CASCARA_SHORTCODE_BASE_PATH . '/vc-setup.php' );
  if (is_plugin_active('js_composer/js_composer.php')) {
    require_once( CASCARA_SHORTCODE_BASE_PATH . '/lib/lib.php' );
  }
  require_once( CASCARA_PLUGIN_INC . '/custom-shortcodes/theme-shortcodes.php' );
  require_once( CASCARA_PLUGIN_INC . '/custom-shortcodes/custom-shortcodes.php' );
  require_once( CASCARA_PLUGIN_INC . '/load-more/malinky-ajax-pagination-functions.php' );
  require_once( CASCARA_PLUGIN_INC . '/load-more/malinky-ajax-pagination.php' );

  // Widgets
  require_once( CASCARA_PLUGIN_INC . '/widgets/weather-report.php' );
  // require_once( CASCARA_PLUGIN_INC . '/widgets/social-counter.php' );
  require_once( CASCARA_PLUGIN_INC . '/widgets/nav-widget.php' );
  require_once( CASCARA_PLUGIN_INC . '/widgets/recent-posts.php' );
  require_once( CASCARA_PLUGIN_INC . '/widgets/text-widget.php' );
  require_once( CASCARA_PLUGIN_INC . '/widgets/widget-extra-fields.php' );

}

/**
 * Plugin language
 */
function cascara_plugin_language_setup() {
  load_plugin_textdomain( 'cascara-core', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );
}
add_action( 'init', 'cascara_plugin_language_setup' );

/* WPAUTOP for shortcode output */
if( ! function_exists( 'cascara_set_wpautop' ) ) {
  function cascara_set_wpautop( $content, $force = true ) {
    if ( $force ) {
      $content = wpautop( preg_replace( '/<\/?p\>/', "\n", $content ) . "\n" );
    }
    return do_shortcode( shortcode_unautop( $content ) );
  }
}

/* Use shortcodes in text widgets */
add_filter('widget_text', 'do_shortcode');

/* Shortcodes enable in the_excerpt */
add_filter('the_excerpt', 'do_shortcode');

/* Remove p tag and add by our self in the_excerpt */
remove_filter('the_excerpt', 'wpautop');

/* Add Extra Social Fields in Admin User Profile */
function cascara_add_twitter_facebook( $contactmethods ) {
  $contactmethods['facebook']   = 'Facebook';
  $contactmethods['twitter']    = 'Twitter';
  $contactmethods['pinterest']  = 'Pinterest';
  return $contactmethods;
}
add_filter('user_contactmethods','cascara_add_twitter_facebook',10,1);

/* Share Options */
if ( ! function_exists( 'cascara_wp_share_option' ) ) {
  function cascara_wp_share_option() {

    global $post;
    $page_url = get_permalink($post->ID );
    $title = $post->post_title;
    $share_text = cs_get_option('share_text');
    $share_text = $share_text ? $share_text : esc_html__( 'Share', 'cascara' );
    $share_on_text = cs_get_option('share_on_text');
    $share_on_text = $share_on_text ? $share_on_text : esc_html__( 'Share On', 'cascara' );
    ?>
    <div class="post-share">
      <a href="javascript:void(0);" class="share-link"><i class="fa fa-share-alt" aria-hidden="true"></i></a>
      <div class="cscra-social rounded">
        <a href="//www.facebook.com/sharer/sharer.php?u=<?php print(urlencode($page_url)); ?>&amp;t=<?php print(urlencode($title)); ?>" class="facebook" data-toggle="tooltip" data-placement="top" title="<?php echo esc_attr( $share_on_text .' '); echo esc_html__('Facebook', 'cascara'); ?>" target="_blank"><i class="fa fa-facebook"></i></a>
        <a href="//twitter.com/intent/tweet?text=<?php print(urlencode($title)); ?>&url=<?php print(urlencode($page_url)); ?>" class="twitter" data-toggle="tooltip" data-placement="top" title="<?php echo esc_attr( $share_on_text .' '); echo esc_html__('Twitter', 'cascara'); ?>" target="_blank"><i class="fa fa-twitter"></i></a>
        <a href="//pinterest.com/pin/create/link/?url=<?php print(urlencode($page_url)); ?>" class="pinterest-p" data-toggle="tooltip" data-placement="top" title="<?php echo esc_attr( $share_on_text .' '); echo esc_html__('Pinterest', 'cascara'); ?>" target="_blank"><i class="fa fa-pinterest-p"></i></a>
        <a href="//www.linkedin.com/shareArticle?mini=true&amp;url=<?php print(urlencode($page_url)); ?>&amp;title=<?php print(urlencode($title)); ?>" class="linkedin" data-toggle="tooltip" data-placement="top" title="<?php echo esc_attr( $share_on_text .' '); echo esc_html__('Linkedin', 'cascara'); ?>" target="_blank"><i class="fa fa-linkedin"></i></a>
      </div>
    </div>

<?php
  }
}

/* Custom WordPress admin login logo */
if( ! function_exists( 'cascara_theme_login_logo' ) ) {
  function cascara_theme_login_logo() {
    $login_logo = cs_get_option('brand_logo_wp');
    if($login_logo) {
      $login_logo_url = wp_get_attachment_url($login_logo);
    } else {
      $login_logo_url = CASCARA_IMAGES . '/logo.png';
    }
    if($login_logo) {
    echo "
      <style>
        body.login #login h1 a {
        background: url('$login_logo_url') no-repeat scroll center bottom transparent;
        height: 100px;
        width: 100%;
        margin-bottom:0px;
        }
      </style>";
    }
  }
  add_action('login_head', 'cascara_theme_login_logo');
}

/* WordPress admin login logo link */
if( ! function_exists( 'cascara_login_url' ) ) {
  function cascara_login_url() {
    return site_url();
  }
  add_filter( 'login_headerurl', 'cascara_login_url', 10, 4 );
}

/* WordPress admin login logo link */
if( ! function_exists( 'cascara_login_title' ) ) {
  function cascara_login_title() {
    return get_bloginfo('name');
  }
  add_filter('login_headertext', 'cascara_login_title');
}

// Facebook Fans Count
function cascara_get_fb_fans_count($fbid,$app_id,$app_secret) {
  $urls = 'https://graph.facebook.com/v2.7/'. $fbid . '?fields=fan_count&access_token='. $app_id . '|' . $app_secret;
  $string = @file_get_contents( $urls );
  if($string) {
    $fan_count = json_decode( $string );
    $get_fan_count = $fan_count->fan_count;
    return cascara_restyle_text($get_fan_count);
  }
}

/* WP Registration form in Shortcode */
add_shortcode( 'cascara_registration', 'cascara_registration' );
function cascara_registration() {
    ob_start();
    cascara_registration_function();
    return ob_get_clean();
}

/* Registration Form Function */
function cascara_registration_function() {
  $first_name = $password = $email = '';
  if ( isset($_POST['wp-submit'] ) ) {
    registration_validation(
    $_POST['first_name'],
    $_POST['email'],
    $_POST['password']
    );

    // sanitize user form input
    global $username, $password, $email, $website, $first_name, $last_name, $nickname, $bio;

    $username   =   sanitize_email( $_POST['email'] );
    $password   =   esc_attr( $_POST['password'] );
    $email      =   sanitize_email( $_POST['email'] );
    $first_name =   sanitize_text_field( $_POST['first_name'] );
    // call @function complete_registration to create the user
    // only when no WP_error is found
    complete_registration($username,$password,$email,$first_name
    );
  }

  registration_form($first_name,$email,$password );
}

/* Complete Resgistration Form s*/
function complete_registration() {
  global $reg_errors, $first_name, $email, $password;
  if ( 1 > count( $reg_errors->get_error_messages() ) ) {
    $userdata = array(
    'user_login'    =>   $email,
    'user_email'    =>   $email,
    'user_pass'     =>   $password,
    'first_name'    =>   $first_name,
    );
    $user = wp_insert_user( $userdata );
    //print_r($user);
    if($user)
      echo __('Registration complete. ','cascara');
    else
      echo __('Problem in Registration . ','cascara');
  }
}

/* WP Registration Form Output */
function registration_form( $first_name, $email, $password ) {
  echo '
  <form name="loginform" id="loginform" action="'.( is_ssl() ? 'https://' : 'http://' ).$_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'] . '" method="post">
  <p class="login-username">
            <label for="full_name">Full Name</label>
            <input name="first_name" id="full_name" class="input" placeholder="Your Name" size="20" type="text" value="'.( isset( $_POST['first_name']) ? $first_name : null ).'">
          </p>
          <p class="login-password">
            <label for="email_address">Email Address</label>
            <input name="email" id="email_address" class="input" placeholder="Your Email" size="20" type="email" value="'.( isset( $_POST['email']) ? $email : null ).'">
          </p>
          <p class="login-password">
            <label for="password">Password</label>
            <input name="password" id="password" class="input" placeholder="Your Password" size="20" type="password" value="' . ( isset( $_POST['password'] ) ? $password : null ) . '">
          </p>
          <p class="login-submit">
            <input name="wp-submit" id="wp-submit" class="button-primary" value="Sign up Free" type="submit">
            <input name="redirect_to" value="" type="hidden">
          </p>
  </form>
  ';
}

// Convert Values in K
function cascara_restyle_text($input){
    $input = number_format($input);
    $input_count = substr_count($input, ',');
    if($input_count != '0'){
        if($input_count == '1'){
            return substr($input, 0, -4).'k';
        } else if($input_count == '2'){
            return substr($input, 0, -8).'mil';
        } else if($input_count == '3'){
            return substr($input, 0,  -12).'bil';
        } else {
            return;
        }
    } else {
        return $input;
    }
}

/* Post Views */
if ( ! function_exists( 'cascara_post_views' ) ) {
  function cascara_post_views($postID) {
    global $post;

    echo '<span class="post-views-item"><span class="fa fa-eye icons"></span> ';
    echo cascara_getPostViews($postID);
    echo '</span>';

  }
}

if ( ! function_exists( 'cascara_post_views_two' ) ) {
  function cascara_post_views_two($postID) {
   ?>
      <?php
        echo '<li class="post-views-item-two"><span class="fa fa-eye icons"></span>';
        echo cascara_getPostViews($postID);
        echo esc_html__(' Views','cascara');
        echo '</li>';
      ?>
  <?php
  }
}

/**
 *
 * Encode string for backup options
 *
 * @since 1.0.0
 * @version 1.0.0
 *
 */
if ( ! function_exists( 'cs_encode_string' ) ) {
  function cs_encode_string( $string ) {
    return rtrim( strtr( call_user_func( 'base'. '64' .'_encode', addslashes( gzcompress( serialize( $string ), 9 ) ) ), '+/', '-_' ), '=' );
  }
}

/**
 *
 * Decode string for backup options
 *
 * @since 1.0.0
 * @version 1.0.0
 *
 */
if ( ! function_exists( 'cs_decode_string' ) ) {
  function cs_decode_string( $string ) {
    return unserialize( gzuncompress( stripslashes( call_user_func( 'base'. '64' .'_decode', rtrim( strtr( $string, '-_', '+/' ), '=' ) ) ) ) );
  }
}


/**
 * One Click Install
 * @return Import Demos - Needed Import Demo's
 */
function cascara_import_files() {
  return array(
    array(
      'import_file_name'           => 'Cascara',
      'import_file_url'            => trailingslashit( CASCARA_PLUGIN_URL ) . 'inc/import/content.xml',
      'import_widget_file_url'     => trailingslashit( CASCARA_PLUGIN_URL ) . 'inc/import/widget.wie',
      'local_import_csf'           => array(
        array(
          'file_path'   => trailingslashit( CASCARA_PLUGIN_URL ) . 'inc/import/theme-options.json',
          'option_name' => '_cs_options',
        ),
      ),
      'import_notice'              => __( 'Import process may take 2-4 minutes, please be patient. It\'s really based on your network speed.', 'cascara-core' ),
      'preview_url'                => 'https://victorthemes.com/themes/cascara',
    ),
  );
}
add_filter( 'pt-ocdi/import_files', 'cascara_import_files' );

/**
 * One Click Import Function for CodeStar Framework
 */
if ( ! function_exists( 'csf_after_content_import_execution' ) ) {
  function csf_after_content_import_execution( $selected_import_files, $import_files, $selected_index ) {

    $downloader = new OCDI\Downloader();

    if( ! empty( $import_files[$selected_index]['import_csf'] ) ) {

      foreach( $import_files[$selected_index]['import_csf'] as $index => $import ) {
        $file_path = $downloader->download_file( $import['file_url'], 'demo-csf-import-file-'. $index . '-'. date( 'Y-m-d__H-i-s' ) .'.json' );
        $file_raw  = OCDI\Helpers::data_from_file( $file_path );
        update_option( $import['option_name'], json_decode( $file_raw, true ) );
      }

    } else if( ! empty( $import_files[$selected_index]['local_import_csf'] ) ) {

      foreach( $import_files[$selected_index]['local_import_csf'] as $index => $import ) {
        $file_path = $import['file_path'];
        $file_raw  = OCDI\Helpers::data_from_file( $file_path );
        update_option( $import['option_name'], json_decode( $file_raw, true ) );
      }

    }

    // Put info to log file.
    $ocdi       = OCDI\OneClickDemoImport::get_instance();
    $log_path   = $ocdi->get_log_file_path();

    OCDI\Helpers::append_to_file( 'Codestar Framework files loaded.'. $logs, $log_path );

  }
  add_action('pt-ocdi/after_content_import_execution', 'csf_after_content_import_execution', 3, 99 );
}

/**
 * [cascara_after_import_setup]
 * @return Front Page, Post Page & Menu Set
 */
function cascara_after_import_setup() {
    // Assign menus to their locations.
    $main_menu = get_term_by( 'name', 'Main Menu', 'nav_menu' );

    set_theme_mod( 'nav_menu_locations', array(
        'primary' => $main_menu->term_id,
      )
    );

    // Assign front page and posts page (blog page).
    $front_page_id = get_page_by_title( 'Home Version One' );
    $blog_page_id  = get_page_by_title( 'Blog' );

    update_option( 'show_on_front', 'page' );
    update_option( 'page_on_front', $front_page_id->ID );
    update_option( 'page_for_posts', $blog_page_id->ID );

}
add_action( 'pt-ocdi/after_import', 'cascara_after_import_setup' );

// Install Demos Menu - Menu Edited
function cascara_core_one_click_page( $default_settings ) {
  $default_settings['parent_slug'] = 'themes.php';
  $default_settings['page_title']  = esc_html__( 'Install Demos', 'cascara-core' );
  $default_settings['menu_title']  = esc_html__( 'Install Demos', 'cascara-core' );
  $default_settings['capability']  = 'import';
  $default_settings['menu_slug']   = 'install_demos';

  return $default_settings;
}
add_filter( 'pt-ocdi/plugin_page_setup', 'cascara_core_one_click_page' );

// Model Popup - Width Increased
function cascara_ocdi_confirmation_dialog_options ( $options ) {
  return array_merge( $options, array(
    'width'       => 600,
    'dialogClass' => 'wp-dialog',
    'resizable'   => false,
    'height'      => 'auto',
    'modal'       => true,
  ) );
}
add_filter( 'pt-ocdi/confirmation_dialog_options', 'cascara_ocdi_confirmation_dialog_options', 10, 1 );

// Disable the branding notice - ProteusThemes
add_filter( 'pt-ocdi/disable_pt_branding', '__return_true' );

function ocdi_plugin_intro_text( $default_text ) {
  $auto_install = admin_url('themes.php?page=install_demos');
  $manual_install = admin_url('themes.php?page=install_demos&import-mode=manual');
  $default_text .= '<h1>Install Demos</h1>
  <div class="cascara-core_intro-text vtdemo-one-click">
  <div id="poststuff">

    <div class="postbox important-notes">
      <h3><span>Important notes:</span></h3>
      <div class="inside">
        <ol>
          <li>Please note, this import process will take time. So, please be patient.</li>
          <li>Please make sure you\'ve installed recommended plugins before you import this content.</li>
          <li>All images are demo purposes only. So, images may repeat in your site content.</li>
        </ol>
      </div>
    </div>

    <div class="postbox vt-support-box vt-error-box">
      <h3><span>Don\'t Edit Parent Theme Files:</span></h3>
      <div class="inside">
        <p>Don\'t edit any files from parent theme! Use only a <strong>Child Theme</strong> files for your customizations!</p>
        <p>If you get future updates from our theme, you\'ll lose edited customization from your parent theme.</p>
      </div>
    </div>

    <div class="postbox vt-support-box">
      <h3><span>Need Support?</span> <a href="https://www.youtube.com/watch?v=imw9a_GQAvc" target="_blank" class="cs-section-video"><i class="fa fa-youtube-play"></i> <span>How to?</span></a></h3>
      <div class="inside">
        <p>Have any doubts regarding this installation or any other issues? Please feel free to open a ticket in our support center.</p>
        <a href="https://victorthemes.com/docs/cascara" class="button-primary" target="_blank">Docs</a>
        <a href="https://victorthemes.com/wp-themes/cascara" class="button-primary" target="_blank">Item Page</a>
      </div>
    </div>
    <div class="nav-tab-wrapper vt-nav-tab">
      <a href="'. $auto_install .'" class="nav-tab vt-mode-switch vt-auto-mode nav-tab-active">Auto Import</a>
      <a href="'. $manual_install .'" class="nav-tab vt-mode-switch vt-manual-mode">Manual Import</a>
    </div>

  </div>
  </div>';

  return $default_text;
}
add_filter( 'pt-ocdi/plugin_intro_text', 'ocdi_plugin_intro_text' );