<?php

/**
 * Initialize Custom Post Type - Cascara Theme
 */

function cascara_custom_post_type() {

	$team_cpt = (cascara_framework_active()) ? cs_get_option('theme_team_name') : '';
	$team_slug = (cascara_framework_active()) ? cs_get_option('theme_team_slug') : '';

	$team_base_slug = (isset($team_slug) && $team_slug !== '') ? sanitize_title_with_dashes($team_slug) : ((isset($team_cpt) && $team_cpt !== '') ? strtolower($team_cpt) : 'team');
	$teams = ucfirst((isset($team_cpt) && $team_cpt !== '') ? strtolower($team_cpt) : 'team');

	// Register custom post type - Team
	register_post_type('team',
		array(
			'labels' => array(
				'name' => $teams,
				'singular_name' => sprintf(esc_html__('%s Post', 'cascara-core' ), $teams),
				'all_items' => sprintf(esc_html__('%s', 'cascara-core' ), $teams),
				'add_new' => esc_html__('Add New', 'cascara-core') ,
				'add_new_item' => sprintf(esc_html__('Add New %s', 'cascara-core' ), $teams),
				'edit' => esc_html__('Edit', 'cascara-core') ,
				'edit_item' => sprintf(esc_html__('Edit %s', 'cascara-core' ), $teams),
				'new_item' => sprintf(esc_html__('New %s', 'cascara-core' ), $teams),
				'view_item' => sprintf(esc_html__('View %s', 'cascara-core' ), $teams),
				'search_items' => sprintf(esc_html__('Search %s', 'cascara-core' ), $teams),
				'not_found' => esc_html__('Nothing found in the Database.', 'cascara-core') ,
				'not_found_in_trash' => esc_html__('Nothing found in Trash', 'cascara-core') ,
				'parent_item_colon' => ''
			) ,
			'public' => true,
			'publicly_queryable' => true,
			'exclude_from_search' => false,
			'show_ui' => true,
			'query_var' => true,
			'menu_position' => 10,
			'menu_icon' => 'dashicons-businessman',
			'rewrite' => array(
				'slug' => $team_base_slug,
				'with_front' => false
			),
			'has_archive' => true,
			'capability_type' => 'post',
			'hierarchical' => true,
			'supports' => array(
				'title',
				'editor',
				'thumbnail',
				'excerpt',
				'revisions',
				'sticky',
			)
		)
	);
	// Team - End

}

// After Theme Setup
function cascara_custom_flush_rules() {
	// Enter post type function, so rewrite work within this function
	cascara_custom_post_type();
	// Flush it
	flush_rewrite_rules();
}
register_activation_hook(__FILE__, 'cascara_custom_flush_rules');
add_action('init', 'cascara_custom_post_type');

/* ---------------------------------------------------------------------------
 * Custom columns - Team
 * --------------------------------------------------------------------------- */
add_filter("manage_edit-team_columns", "cascara_team_edit_columns");
function cascara_team_edit_columns($columns) {
  $new_columns['cb'] = '<input type="checkbox" />';
  $new_columns['title'] = __('Title', 'cascara-core' );
  $new_columns['thumbnail'] = __('Image', 'cascara-core' );
  $new_columns['id'] = __('Item ID', 'cascara-core' );
  $new_columns['name'] = __('Job Position', 'cascara-core' );
  $new_columns['date'] = __('Date', 'cascara-core' );

  return $new_columns;
}

add_action('manage_team_posts_custom_column', 'cascara_manage_team_columns', 10, 2);
function cascara_manage_team_columns( $column_name ) {
  global $post;

  switch ($column_name) {

    /* If displaying the 'Image' column. */
    case 'thumbnail':
      echo get_the_post_thumbnail( $post->ID, array( 100, 100) );
    break;

    /* If displaying the 'ID' column. */
    case 'id':
      echo '<input type="text" onfocus="this.select();" readonly="readonly" value="'. esc_attr( $post->ID ) .'">';
    break;

    case "name":
    	$team_options = get_post_meta( get_the_ID(), 'team_options', true );
      echo $team_options['team_job_position'];
    break;

    /* Just break out of the switch statement for everything else. */
    default :
      break;
    break;

  }
}
