<?php

if ( ! function_exists( 'malinky_load_css' ) ) {

    /**
     * Filter used to dequeue styles.
     */
    function malinky_load_css() {
        return apply_filters( 'malinky_load_css', MALINKY_LOAD_CSS );
    }

}

if ( ! function_exists( 'malinky_load_js' ) ) {

    /**
     * Filter used to dequeue scripts.
     */
    function malinky_load_js() {
        return apply_filters( 'malinky_load_js', MALINKY_LOAD_JS );
    }

}

if ( ! function_exists( 'malinky_is_blog_page' ) ) {

    /**
     * Check if current page is the blog home page, archive or optional single.
     * Archive includes category, tag, date, author pages, custom post types.
     *
     * @param bool $single Include is_single()
     *
     * @return bool
     */
    function malinky_is_blog_page( $single = true )
    {
        global $post;
        if ( ! $single )
            return ( is_home() || is_front_page() || is_archive() || is_search() );
        return ( is_home() || is_front_page() || is_archive() || is_search() || is_single() );
    }

}

if ( ! function_exists( 'malinky_ajax_pagination_ajax_loader' ) ) {

    /**
     * Check if a user has uploaded an ajax loader and it is a valid image.
     * If not then use the default loader saved in the plugin folder.
     * Returns an img tag for the ajax loader.
     *
     * @param int|str $ajax_loader the id of the attachment or the str default
     *
     * @return str
     */
    function malinky_ajax_pagination_ajax_loader( $ajax_loader )
    {
        $ajax_loader_img = '<div class="cscra-preloaderr"><div class="loader-wrap"><div class="loader"><div class="loader-inner"><div></div><div></div></div><img class="loader-icon" src="' . CASCARA_PLUGIN_ASTS . '/images/icon4.png" alt="" /></div></div></div>';

        return $ajax_loader_img;
    }

}

if ( ! function_exists( 'malinky_ajax_pagination_theme_defaults' ) ) {

    /**
     * Set up defaults based on popular themes.
     * Returns associative array which is then localized in main-admin.js.
     *
     * @return arr
     */
    function malinky_ajax_pagination_theme_defaults()
    {
        $theme_defaults = array(
            'Venture' => array(
                'posts_wrapper'         => '.blog-items-wrap',
                'post_wrapper'          => '.post-item',
                'pagination_wrapper'    => '.cscra-pagination',
                'next_page_selector'    => '.cscra-pagination .next'
            ),
        );
        return $theme_defaults;
    }

}

if ( ! function_exists( 'malinky_ajax_pagination_theme_default_names' ) ) {

    /**
     * Get the default themes names based on the theme type.
     *
     * @return arr
     */
    function malinky_ajax_pagination_theme_default_names()
    {
        $theme_names = malinky_ajax_pagination_theme_defaults();
        return array_combine( array_keys( $theme_names ), array_keys( $theme_names ) );
    }

}
