<?php
/*
 * All Metabox related options for Cascara theme.
 * Author & Copyright: VictorThemes
 * URL: https://victorthemes.com/wp-themes
 */

function cascara_vt_metabox_options( $options ) {

  $options      = array();

  // -----------------------------------------
  // Post Metabox Options                    -
  // -----------------------------------------
  $options[]    = array(
    'id'        => 'post_type_metabox',
    'title'     => esc_html__('Post Options', 'cascara'),
    'post_type' => 'post',
    'context'   => 'normal',
    'priority'  => 'default',
    'sections'  => array(

      // All Post Formats
      array(
        'name'   => 'section_post_formats',
        'fields' => array(

          // Standard, Image
          array(
            'title' => 'Standard Image',
            'type'  => 'subheading',
            'content' => esc_html__('There is no Extra Option for this Post Format!', 'cascara'),
            'wrap_class' => 'vt-minimal-heading hide-title',
          ),
          // Standard, Image

          // Gallery
          array(
            'type'    => 'notice',
            'title'   => 'Gallery Format',
            'wrap_class' => 'hide-title',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Gallery Format', 'cascara')
          ),
          array(
            'id'          => 'gallery_post_format',
            'type'        => 'gallery',
            'title'       => esc_html__('Add Gallery', 'cascara'),
            'add_title'   => esc_html__('Add Image(s)', 'cascara'),
            'edit_title'  => esc_html__('Edit Image(s)', 'cascara'),
            'clear_title' => esc_html__('Clear Image(s)', 'cascara'),
          ),
          // Gallery

          // Video Post
          array(
            'type'       => 'notice',
            'title'      => 'Video Post',
            'wrap_class' => 'hide-title',
            'class'      => 'info cs-vt-heading',
            'content'    => esc_html__('Video Post', 'cascara')
          ),
          array(
            'id'        => 'video_post',
            'type'      => 'textarea',
            'title'     => esc_html__('Video Iframe Code', 'cascara'),
            'info'      => esc_html__('Enter your video iframe code(You can enter direct watch url for youtube,vimeo and dailymotion. For other video platform you have to enter embed code )', 'cascara'),
            'sanitize'  => true,
          ),
          // Video Post

        ),
      ),

    ),
  );

  // -----------------------------------------
  // Post Metabox Options                    -
  // -----------------------------------------
  $options[]    = array(
    'id'        => 'post_type_options',
    'title'     => esc_html__('Post Layout', 'cascara'),
    'post_type' => 'post',
    'context'   => 'side',
    'priority'  => 'default',
    'sections'  => array(

      // All Post Formats
      array(
        'name'   => 'section_post_options',
        'fields' => array(

          array(
            'id'    => 'full_ban',
            'type'  => 'switcher',
            'title' => esc_html__('Full Width Banner', 'cascara'),
            'info' => esc_html__('Turn On if you want full width banner.', 'cascara'),
            'default' => false,
          ),

        ),
      ),

    ),
  );
  // -----------------------------------------
  // Post Metabox Options                    -
  // -----------------------------------------
  $options[]    = array(
    'id'        => 'post_cat_options',
    'title'     => esc_html__('Post Category Color', 'cascara'),
    'post_type' => 'post',
    'context'   => 'side',
    'priority'  => 'default',
    'sections'  => array(

      // All Post Formats
      array(
        'name'   => 'section_post_cat_options',
        'fields' => array(

          array(
            'id'    => 'cat_color',
            'type'  => 'color_picker',
            'title' => esc_html__('Category Text Color', 'cascara'),
          ),
          array(
            'id'    => 'cat_bg_color',
            'type'  => 'color_picker',
            'title' => esc_html__('Category Background Color', 'cascara'),
          ),

        ),
      ),

    ),
  );

  // -----------------------------------------
  // Page Metabox Options                    -
  // -----------------------------------------
  $options[]    = array(
    'id'        => 'page_type_metabox',
    'title'     => esc_html__('Page Custom Options', 'cascara'),
    'post_type' => array('post', 'page', 'product', 'team'),
    'context'   => 'normal',
    'priority'  => 'default',
    'sections'  => array(

      // Title Section
      array(
        'name'  => 'page_topbar_section',
        'title' => esc_html__('Top Bar', 'cascara'),
        'icon'  => 'fa fa-minus',

        // Fields Start
        'fields' => array(

          array(
            'id'           => 'topbar_options',
            'type'         => 'image_select',
            'title'        => esc_html__('Topbar', 'cascara'),
            'options'      => array(
              'default'     => CASCARA_CS_IMAGES .'/topbar-default.png',
              'custom'      => CASCARA_CS_IMAGES .'/topbar-custom.png',
              'hide_topbar' => CASCARA_CS_IMAGES .'/topbar-hide.png',
            ),
            'attributes' => array(
              'data-depend-id' => 'hide_topbar_select',
            ),
            'radio'     => true,
            'default'   => 'default',
          ),
          array(
            'id'          => 'top_left',
            'type'        => 'textarea',
            'title'       => esc_html__('Top Left', 'cascara'),
            'dependency'  => array('hide_topbar_select', '==', 'custom'),
            'shortcode'       => true,
          ),
          array(
            'id'          => 'top_right',
            'type'        => 'textarea',
            'title'       => esc_html__('Top Right', 'cascara'),
            'dependency'  => array('hide_topbar_select', '==', 'custom'),
            'shortcode'       => true,
          ),
          array(
            'id'          => 'top_center',
            'type'        => 'textarea',
            'title'       => esc_html__('Top Center', 'cascara'),
            'dependency'  => array('hide_topbar_select', '==', 'custom'),
            'shortcode'       => true,
          ),
          array(
            'id'         => 'topbar_left_width',
            'type'       => 'text',
            'title'      => esc_html__('Top Left Width in %', 'cascara'),
            'attributes' => array(
              'placeholder' => '50%'
            ),
            'dependency'  => array('hide_topbar_select', '==', 'custom'),
          ),
          array(
            'id'         => 'topbar_right_width',
            'type'       => 'text',
            'title'      => esc_html__('Top Right Width in %', 'cascara'),
            'attributes' => array(
              'placeholder' => '50%'
            ),
            'dependency'  => array('hide_topbar_select', '==', 'custom'),
          ),
          array(
            'id'         => 'topbar_center_width',
            'type'       => 'text',
            'title'      => esc_html__('Top Center Width in %', 'cascara'),
            'attributes' => array(
              'placeholder' => '50%'
            ),
            'dependency'  => array('hide_topbar_select', '==', 'custom'),
          ),
          array(
            'id'    => 'topbar_bg',
            'type'  => 'color_picker',
            'title' => esc_html__('Topbar Background Color', 'cascara'),
            'dependency'  => array('hide_topbar_select', '==', 'custom'),
          ),
          array(
            'id'    => 'topbar_border',
            'type'  => 'color_picker',
            'title' => esc_html__('Topbar Border Color', 'cascara'),
            'dependency'  => array('hide_topbar_select', '==', 'custom'),
          ),

        ), // End : Fields

      ), // Title Section

      // Header
      array(
        'name'  => 'header_section',
        'title' => esc_html__('Header', 'cascara'),
        'icon'  => 'fa fa-bars',
        'fields' => array(

          array(
            'id'    => 'default_menu_color',
            'type'  => 'color_picker',
            'title' => esc_html__('Menu Color', 'cascara'),
            'info' => esc_html__('Pick your menu color. This color will only apply for non-sticky header mode.', 'cascara'),
          ),
          array(
            'id'    => 'default_menu_hover_color',
            'type'  => 'color_picker',
            'title' => esc_html__('Menu Hover Color', 'cascara'),
            'info' => esc_html__('Pick your menu hover color. This color will only apply for non-sticky header mode.', 'cascara'),
          ),
          array(
            'id'    => 'sticky_menu_color',
            'type'  => 'color_picker',
            'title' => esc_html__('Menu Color', 'cascara'),
            'info' => esc_html__('Pick your menu color. This color will only apply for sticky header mode.', 'cascara'),
          ),
          array(
            'id'    => 'sticky_menu_hover_color',
            'type'  => 'color_picker',
            'title' => esc_html__('Menu Hover Color', 'cascara'),
            'info' => esc_html__('Pick your menu hover color. This color will only apply for sticky header mode.', 'cascara'),
          ),
          array(
            'id'             => 'choose_menu',
            'type'           => 'select',
            'title'          => esc_html__('Choose Menu', 'cascara'),
            'desc'          => esc_html__('Choose custom menus for this page.', 'cascara'),
            'options'        => 'menus',
            'default_option' => esc_html__('Select your menu', 'cascara'),
          ),

          // Enable & Disable
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Enable & Disable', 'cascara'),
          ),
          array(
            'id'        => 'sticky_header',
            'type'      => 'select',
            'title'     => esc_html__('Sticky Header', 'cascara'),
            'options'   => array(
              'default'    => 'Default(Theme Options)',
              'sticky' => 'Sticky',
              'not-sticky'   => 'Not Sticky',
            ),
          ),
          array(
            'id'        => 'sticky_footer',
            'type'      => 'select',
            'title'     => esc_html__('Sticky Footer', 'cascara'),
            'options'   => array(
              'default'    => 'Default(Theme Options)',
              'sticky' => 'Sticky',
              'not-sticky'   => 'Not Sticky',
            ),
          ),
          array(
            'id'        => 'search_icon',
            'type'      => 'select',
            'title'     => esc_html__('Search Icon', 'cascara'),
            'options'   => array(
              'default'    => 'Default(Theme Options)',
              'show' => 'Show',
              'hide'   => 'Hide',
            ),
          ),
          array(
            'id'        => 'fixed_navigation',
            'type'      => 'select',
            'title'     => esc_html__('Fixed Navigation', 'cascara'),
            'options'   => array(
              'default'    => 'Default(Theme Options)',
              'show' => 'Show',
              'hide'   => 'Hide',
            ),
          ),
          array(
            'id'        => 'login_signup_icon',
            'type'      => 'select',
            'title'     => esc_html__('Login/Signup Icon', 'cascara'),
            'options'   => array(
              'default'    => 'Default(Theme Options)',
              'show' => 'Show',
              'hide'   => 'Hide',
            ),
          ),

        ),
      ),
      // Header

      // Banner & Title Area
      array(
        'name'  => 'banner_title_section',
        'title' => esc_html__('Banner & Title Area', 'cascara'),
        'icon'  => 'fa fa-bullhorn',
        'fields' => array(

          array(
            'id'        => 'banner_type',
            'type'      => 'select',
            'title'     => esc_html__('Choose Banner Type', 'cascara'),
            'options'   => array(
              'default-title'    => 'Default Title',
              'revolution-slider' => 'Shortcode [Rev Slider]',
              'hide-title-area'   => 'Hide Title/Banner Area',
            ),
          ),
          array(
            'id'    => 'page_revslider',
            'type'  => 'textarea',
            'title' => esc_html__('Revolution Slider or Any Shortcodes', 'cascara'),
            'desc' => esc_html__('Enter any shortcodes that you want to show in this page title area. <br />Eg : Revolution Slider shortcode.', 'cascara'),
            'attributes' => array(
              'placeholder' => esc_html__('Enter your shortcode...', 'cascara'),
            ),
            'dependency'   => array('banner_type', '==', 'revolution-slider'),
          ),
          array(
            'id'    => 'page_custom_title',
            'type'  => 'text',
            'title' => esc_html__('Custom Title', 'cascara'),
            'attributes' => array(
              'placeholder' => esc_html__('Enter your custom title...', 'cascara'),
            ),
            'dependency'   => array('banner_type', '==', 'default-title'),
          ),
          array(
            'id'        => 'title_area_spacings',
            'type'      => 'select',
            'title'     => esc_html__('Title Area Spacings', 'cascara'),
            'options'   => array(
              'padding-none' => esc_html__('Default Spacing', 'cascara'),
              'padding-xs' => esc_html__('Extra Small Padding', 'cascara'),
              'padding-sm' => esc_html__('Small Padding', 'cascara'),
              'padding-md' => esc_html__('Medium Padding', 'cascara'),
              'padding-lg' => esc_html__('Large Padding', 'cascara'),
              'padding-xl' => esc_html__('Extra Large Padding', 'cascara'),
              'padding-no' => esc_html__('No Padding', 'cascara'),
              'padding-custom' => esc_html__('Custom Padding', 'cascara'),
            ),
            'dependency'   => array('banner_type', '==', 'default-title'),
          ),
          array(
            'id'    => 'title_top_spacings',
            'type'  => 'text',
            'title' => esc_html__('Top Spacing', 'cascara'),
            'attributes'  => array( 'placeholder' => '100px' ),
            'dependency'  => array('banner_type|title_area_spacings', '==|==', 'default-title|padding-custom'),
          ),
          array(
            'id'    => 'title_bottom_spacings',
            'type'  => 'text',
            'title' => esc_html__('Bottom Spacing', 'cascara'),
            'attributes'  => array( 'placeholder' => '100px' ),
            'dependency'  => array('banner_type|title_area_spacings', '==|==', 'default-title|padding-custom'),
          ),
          array(
            'id'    => 'titlebar_bg_overlay_color',
            'type'  => 'color_picker',
            'title' => esc_html__('Background Color', 'cascara'),
            'dependency'   => array('banner_type', '==', 'default-title'),
          ),

        ),
      ),
      // Banner & Title Area

      // Content Section
      array(
        'name'  => 'page_content_options',
        'title' => esc_html__('Content Options', 'cascara'),
        'icon'  => 'fa fa-file',

        'fields' => array(

          array(
            'id'        => 'content_spacings',
            'type'      => 'select',
            'title'     => esc_html__('Content Spacings', 'cascara'),
            'options'   => array(
              'padding-none' => esc_html__('Default Spacing', 'cascara'),
              'padding-xs' => esc_html__('Extra Small Padding', 'cascara'),
              'padding-sm' => esc_html__('Small Padding', 'cascara'),
              'padding-md' => esc_html__('Medium Padding', 'cascara'),
              'padding-lg' => esc_html__('Large Padding', 'cascara'),
              'padding-xl' => esc_html__('Extra Large Padding', 'cascara'),
              'padding-cnt-no' => esc_html__('No Padding', 'cascara'),
              'padding-custom' => esc_html__('Custom Padding', 'cascara'),
            ),
            'desc' => esc_html__('Content area top and bottom spacings.', 'cascara'),
          ),
          array(
            'id'    => 'content_top_spacings',
            'type'  => 'text',
            'title' => esc_html__('Top Spacing', 'cascara'),
            'attributes'  => array( 'placeholder' => '100px' ),
            'dependency'  => array('content_spacings', '==', 'padding-custom'),
          ),
          array(
            'id'    => 'content_bottom_spacings',
            'type'  => 'text',
            'title' => esc_html__('Bottom Spacing', 'cascara'),
            'attributes'  => array( 'placeholder' => '100px' ),
            'dependency'  => array('content_spacings', '==', 'padding-custom'),
          ),

        ), // End Fields
      ), // Content Section

      // Copyright
      array(
        'name'  => 'copyright_section',
        'title' => esc_html__('Copyright', 'cascara'),
        'icon'  => 'fa fa-toggle-on',
        'fields' => array(

          array(
            'id'        => 'copyright_style',
            'type'      => 'select',
            'title'     => esc_html__('Content Spacings', 'cascara'),
            'options'   => array(
              'style-one' => esc_html__('Style One', 'cascara'),
              'style-two' => esc_html__('Style Two', 'cascara'),
            ),
            'desc' => esc_html__('Select copyright style.', 'cascara'),
          ),

        ),
      ),
      // Copyright

      // Enable & Disable
      array(
        'name'  => 'hide_show_section',
        'title' => esc_html__('Enable & Disable', 'cascara'),
        'icon'  => 'fa fa-toggle-on',
        'fields' => array(

          array(
            'id'    => 'hide_header',
            'type'  => 'switcher',
            'title' => esc_html__('Hide Header', 'cascara'),
            'label' => esc_html__('Yes, Please do it.', 'cascara'),
          ),
          array(
            'id'    => 'hide_footer',
            'type'  => 'switcher',
            'title' => esc_html__('Hide Footer', 'cascara'),
            'label' => esc_html__('Yes, Please do it.', 'cascara'),
          ),
          array(
            'id'    => 'hide_copyright',
            'type'  => 'switcher',
            'title' => esc_html__('Hide Copyright', 'cascara'),
            'label' => esc_html__('Yes, Please do it.', 'cascara'),
          ),

        ),
      ),
      // Enable & Disable

    ),
  );

  // -----------------------------------------
  // Page Layout
  // -----------------------------------------
  $options[]    = array(
    'id'        => 'page_layout_options',
    'title'     => esc_html__('Page Layout', 'cascara'),
    'post_type' => 'page',
    'context'   => 'side',
    'priority'  => 'default',
    'sections'  => array(

      array(
        'name'   => 'page_layout_section',
        'fields' => array(

          array(
            'id'        => 'page_layout',
            'type'      => 'image_select',
            'options'   => array(
              'full-width'    => CASCARA_CS_IMAGES . '/page-1.png',
              'extra-width'   => CASCARA_CS_IMAGES . '/page-2.png',
              'left-sidebar'  => CASCARA_CS_IMAGES . '/page-3.png',
              'right-sidebar' => CASCARA_CS_IMAGES . '/page-4.png',
            ),
            'attributes' => array(
              'data-depend-id' => 'page_layout',
            ),
            'default'    => 'full-width',
            'radio'      => true,
            'wrap_class' => 'text-center',
          ),
          array(
            'id'            => 'page_sidebar_widget',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Widget', 'cascara'),
            'options'        => cascara_vt_registered_sidebars(),
            'default_option' => esc_html__('Select Widget', 'cascara'),
            'dependency'   => array('page_layout', 'any', 'left-sidebar,right-sidebar'),
          ),

        ),
      ),

    ),
  );

  // -----------------------------------------
  // Team
  // -----------------------------------------
  $options[]    = array(
    'id'        => 'team_options',
    'title'     => esc_html__('Job Position', 'cascara'),
    'post_type' => 'team',
    'context'   => 'side',
    'priority'  => 'default',
    'sections'  => array(

      array(
        'name'   => 'team_option_section',
        'fields' => array(

          array(
            'id'      => 'team_job_position',
            'type'    => 'text',
            'attributes' => array(
              'placeholder' => esc_html__('Eg : Financial Manager', 'cascara'),
            ),
            'info'    => esc_html__('Enter this employee job position, in your company.', 'cascara'),
          ),

        ),
      ),

    ),
  );

  return $options;

}
add_filter( 'cs_metabox_options', 'cascara_vt_metabox_options' );
