<?php
/*
 * Recent Posts Widget
 * Author & Copyright: VictorThemes
 * URL: https://victorthemes.com/wp-themes
 */

class cascara_recent_post extends WP_Widget {

  /**
   * Specifies the widget name, description, class name and instatiates it
   */
  public function __construct() {
    parent::__construct(
      'cascara-recent-post',
      VTHEME_NAME_P . esc_html__( ': Recent Posts With Image', 'cascara-core' ),
      array(
        'classname'   => 'widget-popular',
        'description' => VTHEME_NAME_P . esc_html__( ' widget that displays recent posts with image.', 'cascara-core' )
      )
    );
  }

  /**
   * Generates the back-end layout for the widget
   */
  public function form( $instance ) {
    // Default Values
    $instance   = wp_parse_args( $instance, array(
      'title'    => esc_html__( 'Recent Posts', 'cascara-core' ),
      'style'   => '',
      'ptypes'   => 'post',
      'limit'    => '',
      'date'     => true,
      'category' => '',
      'order' => '',
      'orderby' => '',
      'blink' => '',
      'progress' => '',
    ));

    // Title
    $title_value = esc_attr( $instance['title'] );
    $title_field = array(
      'id'    => $this->get_field_name('title'),
      'name'  => $this->get_field_name('title'),
      'type'  => 'text',
      'title' => esc_html__( 'Title :', 'cascara-core' ),
      'wrap_class' => 'cascara-cs-widget-fields',
    );
    echo cs_add_element( $title_field, $title_value );

    // Style
    $style_value = esc_attr( $instance['style'] );
    $style_field = array(
      'id'    => $this->get_field_name('style'),
      'name'  => $this->get_field_name('style'),
      'type' => 'select',
      'options'   => array(
        'style-one' => 'Style One',
        'style-two' => 'Style Two',
        'style-three' => 'Style Three',
      ),
      'title' => esc_html__( 'Style :', 'cascara-core' ),
    );
    echo cs_add_element( $style_field, $style_value );

    // Post Type
    $ptypes_value = esc_attr( $instance['ptypes'] );
    $ptypes_field = array(
      'id'    => $this->get_field_name('ptypes'),
      'name'  => $this->get_field_name('ptypes'),
      'type' => 'select',
      'options' => 'post_types',
      'default_option' => esc_html__( 'Select Post Type', 'cascara-core' ),
      'title' => esc_html__( 'Post Type :', 'cascara-core' ),
    );
    echo cs_add_element( $ptypes_field, $ptypes_value );

    // Limit
    $limit_value = esc_attr( $instance['limit'] );
    $limit_field = array(
      'id'    => $this->get_field_name('limit'),
      'name'  => $this->get_field_name('limit'),
      'type'  => 'text',
      'title' => esc_html__( 'Limit :', 'cascara-core' ),
      'info' => esc_html__( 'How many posts want to show?', 'cascara-core' ),
    );
    echo cs_add_element( $limit_field, $limit_value );

    // Date
    $date_value = esc_attr( $instance['date'] );
    $date_field = array(
      'id'    => $this->get_field_name('date'),
      'name'  => $this->get_field_name('date'),
      'type'  => 'switcher',
      'on_text'  => esc_html__( 'Yes', 'cascara-core' ),
      'off_text'  => esc_html__( 'No', 'cascara-core' ),
      'title' => esc_html__( 'Display Date :', 'cascara-core' ),
    );
    echo cs_add_element( $date_field, $date_value );

    // Category
    $category_value = esc_attr( $instance['category'] );
    $category_field = array(
      'id'    => $this->get_field_name('category'),
      'name'  => $this->get_field_name('category'),
      'type'  => 'text',
      'title' => esc_html__( 'Category :', 'cascara-core' ),
      'info' => esc_html__( 'Enter category slugs with comma(,) for multiple items', 'cascara-core' ),
    );
    echo cs_add_element( $category_field, $category_value );

    // Order
    $order_value = esc_attr( $instance['order'] );
    $order_field = array(
      'id'    => $this->get_field_name('order'),
      'name'  => $this->get_field_name('order'),
      'type' => 'select',
      'options'   => array(
        'ASC' => 'Ascending',
        'DESC' => 'Descending',
      ),
      'default_option' => esc_html__( 'Select Order', 'cascara-core' ),
      'title' => esc_html__( 'Order :', 'cascara-core' ),
    );
    echo cs_add_element( $order_field, $order_value );

    // Orderby
    $orderby_value = esc_attr( $instance['orderby'] );
    $orderby_field = array(
      'id'    => $this->get_field_name('orderby'),
      'name'  => $this->get_field_name('orderby'),
      'type' => 'select',
      'options'   => array(
        'none' => esc_html__('None', 'cascara-core'),
        'ID' => esc_html__('ID', 'cascara-core'),
        'author' => esc_html__('Author', 'cascara-core'),
        'title' => esc_html__('Title', 'cascara-core'),
        'name' => esc_html__('Name', 'cascara-core'),
        'type' => esc_html__('Type', 'cascara-core'),
        'date' => esc_html__('Date', 'cascara-core'),
        'modified' => esc_html__('Modified', 'cascara-core'),
        'rand' => esc_html__('Random', 'cascara-core'),
      ),
      'default_option' => esc_html__( 'Select OrderBy', 'cascara-core' ),
      'title' => esc_html__( 'OrderBy :', 'cascara-core' ),
    );
    echo cs_add_element( $orderby_field, $orderby_value );

    // Show Blinking Dot
    $blink_value = esc_attr( $instance['blink'] );
    $blink_field = array(
      'id'    => $this->get_field_name('blink'),
      'name'  => $this->get_field_name('blink'),
      'type'  => 'switcher',
      'on_text'  => __( 'Yes', 'livesay' ),
      'off_text'  => __( 'No', 'livesay' ),
      'title' => __( 'Blink Dot :', 'livesay' ),
      'info' => __( 'Enable this to display blinking dot.(Only For Style One)', 'livesay' ),
    );
    echo cs_add_element( $blink_field, $blink_value );

    // Show Progress Bar
    $progress_value = esc_attr( $instance['progress'] );
    $progress_field = array(
      'id'    => $this->get_field_name('progress'),
      'name'  => $this->get_field_name('progress'),
      'type'  => 'switcher',
      'on_text'  => __( 'Yes', 'livesay' ),
      'off_text'  => __( 'No', 'livesay' ),
      'title' => __( 'Progress Bar :', 'livesay' ),
      'info' => __( 'Enable this to display progress bar.(If you switch On this, posts will display as per posts views. Progress bar will display only in style one)', 'livesay' ),
    );
    echo cs_add_element( $progress_field, $progress_value );

  }

  /**
   * Processes the widget's values
   */
  public function update( $new_instance, $old_instance ) {
    $instance = $old_instance;

    // Update values
    $instance['title']        = strip_tags( stripslashes( $new_instance['title'] ) );
    $instance['style']        = strip_tags( stripslashes( $new_instance['style'] ) );
    $instance['ptypes']       = strip_tags( stripslashes( $new_instance['ptypes'] ) );
    $instance['limit']        = strip_tags( stripslashes( $new_instance['limit'] ) );
    $instance['date']         = strip_tags( stripslashes( $new_instance['date'] ) );
    $instance['category']     = strip_tags( stripslashes( $new_instance['category'] ) );
    $instance['order']        = strip_tags( stripslashes( $new_instance['order'] ) );
    $instance['orderby']      = strip_tags( stripslashes( $new_instance['orderby'] ) );
    $instance['blink']      = strip_tags( stripslashes( $new_instance['blink'] ) );
    $instance['progress']      = strip_tags( stripslashes( $new_instance['progress'] ) );

    return $instance;
  }

  /**
   * Output the contents of the widget
   */
  public function widget( $args, $instance ) {
    // Extract the arguments
    extract( $args );

    $title          = apply_filters( 'widget_title', $instance['title'] );
    $style         = $instance['style'];
    $ptypes         = $instance['ptypes'];
    $limit          = $instance['limit'];
    $display_date   = $instance['date'];
    $category       = $instance['category'];
    $order          = $instance['order'];
    $orderby        = $instance['orderby'];
    $blink        = $instance['blink'];
    $progress        = $instance['progress'];

if($progress){
   $args = array(
    'posts_per_page'  => (int)$limit,  /* get 4 posts, or set -1 for all */
    'orderby'      => 'meta_value_num',  /* this will look at the meta_key you set below */
    'meta_key'     => 'post_views_count',
    'order'        => 'DESC',
    'post_type' => esc_attr($ptypes),
    // 'post_status'  => 'publish'
  );
} else {
  $args = array(
    // other query params here,
    'post_type' => esc_attr($ptypes),
    'posts_per_page' => (int)$limit,
    'orderby' => esc_attr($orderby),
    'order' => esc_attr($order),
    'category_name' => esc_attr($category),
    'ignore_sticky_posts' => 1,
   );
}

// Image Link
$image_link_wrap = cs_get_option('image_link_wrap');
// Lazy Load
$theme_lazyload = cs_get_option('theme_lazyload');

$cascara_rpw = new WP_Query( $args );

     // $cascara_rpw = new WP_Query( $args );
     global $post;

    // Display the markup before the widget
    echo $before_widget;

    if ( $title ) {
      echo $before_title . $title . $after_title;
    }

    if($style === 'style-two') {
      $style_cls = ' items-style-five';
    } elseif($style === 'style-three') {
      $style_cls = ' items-style-four';
    } else {
      $style_cls = '';
    }
    $count=1;
    if ($cascara_rpw->have_posts()) :

    ?>
    <div class="post-items-wrap <?php echo esc_attr($style_cls); ?>">
      <div class="row">
    <?php
      while ($cascara_rpw->have_posts()) : $cascara_rpw->the_post();
        $cascara_post_type = get_post_meta( get_the_ID(), 'post_type_metabox', true );
        if($image_link_wrap) {
          $image_link_class = ' hav-link';
        } else {
          $image_link_class = ' dnt-hav-link';
        }
        if($style === 'style-two') { ?>
          <div class="post-item">
            <div class="cscra-image <?php echo $image_link_class; ?>">
              <?php
                $cascara_large_image =  wp_get_attachment_image_src( get_post_thumbnail_id(get_the_ID()), 'fullsize', false, '' );
                $cascara_large_image = $cascara_large_image[0];

                if(class_exists('Aq_Resize')) {
                  $image_large = aq_resize( $cascara_large_image, '315', '160', true );
                } else {
                  $image_large = $cascara_large_image;
                }
                $large_img_actual = ( $image_large ) ? $image_large : $cascara_large_image;

                  if ( get_post_format() === 'video' ) {
                    if($cascara_post_type){
                      $video_post = $cascara_post_type['video_post'];
                    } else {
                      $video_post = '';
                    }
                    if ($cascara_large_image) {
                    if($image_link_wrap) { ?>
                      <a class="image-link" href="<?php echo esc_url(get_the_permalink()); ?>">
                    <?php }
                    if(!$theme_lazyload) { ?>
                    <img src="<?php echo esc_url($large_img_actual); ?>" alt="<?php echo get_the_title(); ?>">
                    <?php } else { ?>
                      <img data-src="<?php echo esc_url($large_img_actual); ?>" src="<?php echo CASCARA_IMAGES ?>/315x160.jpg" alt="<?php echo get_the_title(); ?>">
                    <?php } if($image_link_wrap) { ?>
                      </a>
                    <?php } ?>
                      <div class="post-info">
                        <?php if ( ! empty( $cascara_post_type['video_post'] ) ) { ?>
                          <a href="<?php echo esc_url($video_post); ?>" class="play-icon widget-play-icon cscra-popup-video"></a>
                        <?php } ?>
                        <h5 class="post-title"><a href="<?php esc_url(the_permalink()) ?>"><?php the_title(); ?></a></h5>
                      </div>
                    <?php }
                  } else {
                    if ($cascara_large_image) {
                    if($image_link_wrap) { ?>
                      <a href="<?php echo esc_url(get_the_permalink()); ?>">
                    <?php } if(!$theme_lazyload) { ?>
                      <img src="<?php echo esc_url($large_img_actual); ?>" alt="<?php echo get_the_title(); ?>">
                    <?php } else { ?>
                      <img data-src="<?php echo esc_url($large_img_actual); ?>" src="<?php echo CASCARA_IMAGES ?>/315x160.jpg" alt="<?php echo get_the_title(); ?>">
                    <?php } if($image_link_wrap) { ?>
                      </a>
                    <?php } } ?>
                      <div class="post-info">
                        <h5 class="post-title"><a href="<?php esc_url(the_permalink()) ?>"><?php the_title(); ?></a></h5>
                      </div>
                  <?php } ?>
            </div>
          </div>
          <?php } elseif($style === 'style-three') { ?>
              <div class="post-item">
                <div class="cscra-image cscra-item">
                  <?php
                    $cascara_post_imgg = wp_get_attachment_image_src( get_post_thumbnail_id(), 'fullsize', false, '' );
                    if($cascara_post_imgg) {
                      $cascara_post_imgg = $cascara_post_imgg[0];
                      
                      if(class_exists('Aq_Resize')) {
                        $cascara_post_img = aq_resize( $cascara_post_imgg, '110', '100', true );
                      } else {
                        $cascara_post_img = $cascara_post_imgg;
                      }
                      if(!$theme_lazyload) {
                        $cascara_post_img_actual = '<img src="'.esc_url($cascara_post_img).'" alt="'.get_the_title().'">';
                      } else {
                        $cascara_post_img_actual = '<img data-src="'.esc_url($cascara_post_img).'" src="'.CASCARA_IMAGES . '/110x100.jpg" alt="'.get_the_title().'">';
                      }
                    } else {
                      $cascara_post_img_actual = '';
                    }
                  ?>
                  <?php
                  if($image_link_wrap) { ?>
                    <a href="<?php echo esc_url(get_the_permalink()); ?>">
                  <?php }
                  echo $cascara_post_img_actual;
                  if($image_link_wrap) { ?>
                    </a>
                  <?php } ?>
                </div>
                <div class="post-info cscra-item">
                  <div class="cscra-table-wrap">
                    <div class="cscra-align-wrap">
                      <div class="post-meta">
                        <ul>
                          <li><i class="fa fa-clock-o" aria-hidden="true"></i> <?php echo esc_html(get_the_date()); ?></li>
                          <?php if (get_comments_number()!=0) { ?>
                          <li><?php echo '<i class="fa fa-commenting-o"></i>';
                            comments_popup_link( '0', '1', '%', '', '' );  ?></li>
                          <?php } ?>
                        </ul>
                      </div>
                      <h5 class="post-title"><a href="<?php esc_url(the_permalink()) ?>"><?php the_title(); ?></a></h5>
                    </div>
                  </div>
                </div>
              </div>

          <?php } else {
            if($count===1){
              $d = cascara_getPostViews(get_the_ID());;
            }
            $post_view = cascara_getPostViews(get_the_ID());;
            if($progress){
              $style_cls = ' with-progress-bar';
            } else {
              $style_cls = '';
            }
           ?>
            <div class="col-md-6 col-sm-3">
              <div class="post-item cscra-item <?php echo esc_attr($style_cls); ?> aa">
                <div class="cscra-image">
                <?php

                  $vieww = strip_tags($post_view, '');
                  $high_view = strip_tags($d, '');

                  $percent = $vieww/$high_view;
                  $percentage = number_format( $percent * 100, 2 ) . '%';

                  $cascara_post_imgg = wp_get_attachment_image_src( get_post_thumbnail_id(), 'fullsize', false, '' );
                  $cascara_post_imgg = $cascara_post_imgg[0];
                  if(class_exists('Aq_Resize')) {
                    $cascara_post_img = aq_resize( $cascara_post_imgg, '150', '140', true );
                  } else {
                    $cascara_post_img = $cascara_post_imgg;
                  }
                  if($cascara_post_img){
                    if(!$theme_lazyload) {
                      $cascara_post_img_actual = '<img src="'.esc_url($cascara_post_img).'" alt="'.get_the_title().'">';
                    } else {
                      $cascara_post_img_actual = '<img data-src="'.esc_url($cascara_post_img).'" src="'.CASCARA_IMAGES . '/150x140.jpg" alt="'.get_the_title().'">';
                    }
                  } else {
                    $cascara_post_img_actual = '';
                  }
                ?>
                  <?php
                  if($image_link_wrap) { ?>
                    <a href="<?php echo esc_url(get_the_permalink()); ?>">
                  <?php }
                  echo $cascara_post_img_actual;
                  if($image_link_wrap) { ?>
                    </a>
                  <?php }
                  if ( function_exists( 'cascara_post_views' ) ) {
                    cascara_post_views(get_the_ID());
                  } ?>
                </div>
                <div class="post-info">
                <?php if($blink){ ?>
                  <span class="title-blink"><i class="fa fa-circle text-danger blink"></i></span>
                <?php } ?>
                  <h5 class="post-title"><a href="<?php esc_url(the_permalink()) ?>"><?php the_title(); ?></a></h5>
                  <?php if($progress){ ?>
                      <div class="progress-item">
                      <div class="progress">
                        <div class="progress-bar" role="progressbar" data-percent="<?php echo $percentage;?>"><span class="progress-counter"></span></div>
                      </div>
                      </div>

                  <?php } ?>
                </div>
              </div>
            </div>
          <?php }
          $count++;
      endwhile;
       ?>
    </div>
  </div>
    <?php endif;
    wp_reset_postdata();
    // Display the markup after the widget
    echo $after_widget;
  }
}

// Register the widget using an annonymous function
function cascara_recent_post_function() {
  register_widget( "cascara_recent_post" );
}
add_action( 'widgets_init', 'cascara_recent_post_function' );
