<?php
/*
 * Social Counter Widget
 * Author & Copyright: VictorThemes
 * URL: https://victorthemes.com/wp-themes
 */

class cascara_social_widget extends WP_Widget {

  /**
   * Specifies the widget name, description, class name and instatiates it
   */
  public function __construct() {
    parent::__construct(
      'widget-social',
      VTHEME_NAME_P . __( ': Social Counter', 'cascara' ),
      array(
        'classname'   => 'widget-social',
        'description' => VTHEME_NAME_P . __( ' widget that displays social counter.', 'cascara' )
      )
    );
  }

  /**
   * Generates the back-end layout for the widget
   */
  public function form( $instance ) {
    // Default Values
    $instance   = wp_parse_args( $instance, array(
      'title'    => '',
      'content'    => '',
      'image'    => '',
      'page_name' => '',
      'app_id' => '',
      'app_secret' => '',
      'twitter_link' => '',
    ));

    // Title
    $title_value = esc_attr( $instance['title'] );
    $title_field = array(
      'id'    => $this->get_field_name('title'),
      'name'  => $this->get_field_name('title'),
      'type'  => 'text',
      'title' => __( 'Title :', 'cascara' ),
      'wrap_class' => 'vt-cs-widget-fields',
    );
    echo cs_add_element( $title_field, $title_value );

    // Content
    $content_value = esc_attr( $instance['content'] );
    $content_field = array(
      'id'    => $this->get_field_name('content'),
      'name'  => $this->get_field_name('content'),
      'type'  => 'text',
      'title' => __( 'Content :', 'cascara' ),
      'wrap_class' => 'vt-cs-widget-fields',
    );
    echo cs_add_element( $content_field, $content_value );

    // Image
    $image_value = esc_attr( $instance['image'] );
    $image_field = array(
      'id'    => $this->get_field_name('image'),
      'name'  => $this->get_field_name('image'),
      'type'  => 'image',
      'title' => esc_html__( 'Upload Image :', 'groppe' ),
    );
    echo cs_add_element( $image_field, $image_value );

    // Page name
    $page_name_value = esc_attr( $instance['page_name'] );
    $page_name_field = array(
      'id'    => $this->get_field_name('page_name'),
      'name'  => $this->get_field_name('page_name'),
      'type'  => 'text',
      'title' => __( 'Facebook Page Name :', 'cascara' ),
    );
    echo cs_add_element( $page_name_field, $page_name_value );

    // App Id
    $app_id_value = esc_attr( $instance['app_id'] );
    $app_id_field = array(
      'id'    => $this->get_field_name('app_id'),
      'name'  => $this->get_field_name('app_id'),
      'type'  => 'text',
      'title' => __( 'Facebook App Id :', 'cascara' ),
    );
    echo cs_add_element( $app_id_field, $app_id_value );

    // App Secret
    $app_secret_value = esc_attr( $instance['app_secret'] );
    $app_secret_field = array(
      'id'    => $this->get_field_name('app_secret'),
      'name'  => $this->get_field_name('app_secret'),
      'type'  => 'text',
      'title' => __( 'Facebook App Secret :', 'cascara' ),
    );
    echo cs_add_element( $app_secret_field, $app_secret_value );

    // Twitter Link
    $twitter_link_value = esc_attr( $instance['twitter_link'] );
    $twitter_link_field = array(
      'id'    => $this->get_field_name('twitter_link'),
      'name'  => $this->get_field_name('twitter_link'),
      'type'  => 'text',
      'title' => __( 'Twitter Link :', 'cascara' ),
    );
    echo cs_add_element( $twitter_link_field, $twitter_link_value );

  }

  /**
   * Processes the widget's values
   */
  public function update( $new_instance, $old_instance ) {
    $instance = $old_instance;

    // Update values
    $instance['title']      = strip_tags( stripslashes( $new_instance['title'] ) );
    $instance['content']      = strip_tags( stripslashes( $new_instance['content'] ) );
    $instance['image']      = strip_tags( stripslashes( $new_instance['image'] ) );
    $instance['page_name']    = strip_tags( stripslashes( $new_instance['page_name'] ) );
    $instance['app_id']   = strip_tags( stripslashes( $new_instance['app_id'] ) );
    $instance['app_secret']   = strip_tags( stripslashes( $new_instance['app_secret'] ) );
    $instance['twitter_link']   = strip_tags( stripslashes( $new_instance['twitter_link'] ) );

    return $instance;
  }

  /**
   * Output
   */
  public function widget( $args, $instance ) {
    // Extract the arguments
    extract( $args );

    $title      = apply_filters( 'widget_title', $instance['title'] );
    $content    = $instance['content'];
    $page_name    = $instance['page_name'];
    $image    = $instance['image'];
    $app_id   = $instance['app_id'];
    $app_secret   = $instance['app_secret'];
    $twitter_link   = $instance['twitter_link'];

    $id = $app_id ? $app_id : '211474789258476';
    $name = $page_name ? $page_name : 'envato';
    $secret = $app_secret ? $app_secret : '524f27872a94f9c331a52d5e8221ca5c';
    $twitter_link = $twitter_link ? $twitter_link : 'https://twitter.com/';

    // Display the markup before the widget
    echo $before_widget;
    if ( $title ) {
      echo $before_title . $title . $after_title;
    }
    $image = wp_get_attachment_url( $image );
    ?>

    <div class="cscra-social-counter">
      <?php if($image){ ?>
        <div class="social-cuntr-img">
          <img class="grop-ftr_image" src="<?php echo esc_url( $image ); ?>" alt="#" />
        </div>
      <?php } ?>
      <div class="social-cuntr-content">
        <h3 class="social-cuntr-title"><?php echo $content; ?></h3>
        <a href="https://www.facebook.com/<?php echo esc_attr($name);?>" target="_blank"><span class="social-fb-button"><i class="fa fa-facebook"></i><?php echo cascara_get_fb_fans_count($name,$id,$secret); ?> <?php echo esc_html__(' Likes','cascara'); ?></span></a>
        <a href="<?php echo esc_url($twitter_link); ?>" target="_blank"><span class="social-twtr-button"><i class="fa fa-twitter"></i><?php echo esc_html__('Follow','cascara'); ?></span></a>
      </div>
    </div>
<?php

    // Display the markup after the widget
    echo $after_widget;
  }
}

// Register the widget using an annonymous function
function cascara_social_widget_function() {
  register_widget( "cascara_social_widget" );
}
add_action( 'widgets_init', 'cascara_social_widget_function' );
