<?php
/*
 * Weather Widget
 * Author & Copyright: VictorThemes
 * URL: https://victorthemes.com/wp-themes
 */

class cascara_weather_widget extends WP_Widget {

  /**
   * Specifies the widget name, description, class name and instatiates it
   */
  public function __construct() {
    parent::__construct(
      'widget-weather',
      VTHEME_NAME_P . __( ': Weather', 'cascara' ),
      array(
        'classname'   => 'widget-weather',
        'description' => VTHEME_NAME_P . __( ' widget that displays weather report.', 'cascara' )
      )
    );
  }

  /**
   * Generates the back-end layout for the widget
   */
  public function form( $instance ) {
    // Default Values
    $instance   = wp_parse_args( $instance, array(
      'title'    => '',
      'latitude' => '',
      'longitude' => '',
    ));

    // Title
    $title_value = esc_attr( $instance['title'] );
    $title_field = array(
      'id'    => $this->get_field_name('title'),
      'name'  => $this->get_field_name('title'),
      'type'  => 'text',
      'title' => __( 'Title :', 'cascara' ),
      'wrap_class' => 'vt-cs-widget-fields',
    );
    echo cs_add_element( $title_field, $title_value );

    // latitude
    $latitude_value = esc_attr( $instance['latitude'] );
    $latitude_field = array(
      'id'    => $this->get_field_name('latitude'),
      'name'  => $this->get_field_name('latitude'),
      'type'  => 'text',
      'title' => __( 'City Latitude :', 'cascara' ),
    );
    echo cs_add_element( $latitude_field, $latitude_value );

    // Button Text
    $longitude_value = esc_attr( $instance['longitude'] );
    $longitude_field = array(
      'id'    => $this->get_field_name('longitude'),
      'name'  => $this->get_field_name('longitude'),
      'type'  => 'text',
      'title' => __( 'City Logitude :', 'cascara' ),
    );
    echo cs_add_element( $longitude_field, $longitude_value );

  }

  /**
   * Processes the widget's values
   */
  public function update( $new_instance, $old_instance ) {
    $instance = $old_instance;

    // Update values
    $instance['title']      = strip_tags( stripslashes( $new_instance['title'] ) );
    $instance['latitude']    = strip_tags( stripslashes( $new_instance['latitude'] ) );
    $instance['longitude']   = strip_tags( stripslashes( $new_instance['longitude'] ) );

    return $instance;
  }

  /**
   * Output the latitudes of the widget
   */
  public function widget( $args, $instance ) {
    // Extract the arguments
    extract( $args );

    $title      = apply_filters( 'widget_title', $instance['title'] );
    $latitude    = $instance['latitude'];
    $longitude   = $instance['longitude'];

    // Display the markup before the widget
    echo $before_widget;
    if ( $title ) {
      echo $before_title . $title . $after_title;
    }

    $weather_lat = ($latitude) ? $latitude : -33.868820;
    $weather_lon = ($longitude) ? $longitude : 151.209296;

    $url = "http://query.yahooapis.com/v1/public/yql";

    $yql_query = 'SELECT * from weather.forecast WHERE woeid in (SELECT woeid FROM geo.places WHERE text="('.$weather_lat.','.$weather_lon.')")';
    $yql_query_url = $url . "?q=" . urlencode($yql_query) . "&format=json";

    $get_data = @file_get_contents($yql_query_url);

    if(!$get_data || $get_data == NULL) {
      $temp = __('Undefined', 'cascara');
      $city = '';
      $weather_icon = 'wi-na';
      $weather_conditions = [];
      $country = '';
      $phpObj = '';
    } else {
      $phpObj = json_decode($get_data);
      if($phpObj->query->results != NULL){
        $city = $phpObj->query->results->channel->location->city;
        $country = $phpObj->query->results->channel->location->country;
        $weather = $phpObj->query->results->channel->item->condition;
        $temp = number_format((($weather->temp - 32) * 5/9), 1, '.', '');
        $weather_conditions = array(
          'cloudy'                  => 'wi-cloudy',
          'partly-cloudy'           => 'wi-cloud',
          'mostly-cloudy'           => 'wi-cloudy',
          'mostly-sunny'            => 'wi-day-sunny',
          'sunny'                   => 'wi-day-sunny',
          'scattered-thunderstorms' => 'wi-storm-showers',
          'isolated-thundershowers' => 'wi-storm-showers',
          'isolated-thunderstorms'  => 'wi-storm-showers',
          'severe-thunderstorms'    => 'wi-storm-showers',
          'thundershowers'          => 'wi-storm-showers',
          'thunderstorms'           => 'wi-storm-showers',
          'hail'                    => 'wi-storm-showers',
          'scattered-snow-showers'  => 'wi-snow',
          'mixed-rain-and-sleet'    => 'wi-snow',
          'mixed-snow-and-sleet'    => 'wi-snow',
          'mixed-rain-and-snow'     => 'wi-snow',
          'light-snow-showers'      => 'wi-snow',
          'snow-flurries'           => 'wi-snow',
          'blowing-snow'            => 'wi-snow',
          'snow-showers'            => 'wi-snow',
          'heavy-snow'              => 'wi-snow',
          'sleet'                   => 'wi-snow',
          'snow'                    => 'wi-snow',
          'mixed-rain-and-hail'     => 'wi-hail',
          'scattered-showers'       => 'wi-snow',
          'freezing-drizzle'        => 'wi-sprinkle',
          'freezing-rain'           => 'wi-rain-mix',
          'light-rain'              => 'wi-rain',
          'drizzle'                 => 'wi-sleet',
          'showers'                 => 'wi-showers',
          'fog'                     => 'wi-fog',
          'haze'                    => 'wi-day-haze',
          'blustery'                => 'wi-strong-wind',
          'windy'                   => 'wi-windy',
          'clear'                   => 'wi-night-clear',
          'mostly-clear'            => 'wi-night-clear',
          'fair'                    => 'wi-cloud',
          'breezy'                  => 'wi-strong-wind'
        );
        $present_weather = str_replace(' ', '-', strtolower($weather->text));
        if(array_key_exists($present_weather, $weather_conditions)){
          $weather_icon = $weather_conditions[$present_weather];
        } else {
          $weather_icon = 'wi-na';
        }
      } else {
        $temp = __('Undefined', 'cascara');
        $city = '';
        $country = '';
        $weather_icon = 'wi-na';
        $weather_conditions = [];
      }
    }

    echo '<div class="weather">';
    if($phpObj) {
      echo '<h4 class="weather-city">'.$city .', '.$country.'</h4><div class="weather-inner-wrap"><div class="weather-icon"><i class="wi '. $weather_icon .'"></i></div><div class="weather-units"><div class="weather-rate">'.$temp.'°<h6 class="weather-unit">celsius</h6></div></div></div> ';

      echo '<h5 class="weather-day">'.gmdate( 'l', ( time() + ( get_option( 'gmt_offset' ) * HOUR_IN_SECONDS ) )).'</h5>';

      echo '<ul>';
      // First Day
      echo '<li><span>'.$phpObj->query->results->channel->item->forecast[1]->day.'</span> ';
      $present_weather = str_replace(' ', '-', strtolower($phpObj->query->results->channel->item->forecast[1]->text));
      if(array_key_exists($present_weather, $weather_conditions)){
        $weather_icon = $weather_conditions[$present_weather];
      } else {
        $weather_icon = 'wi-na';
      }
      echo '<span class="wethr-temp"><i class="wi '. $weather_icon .'"></i>'.sprintf("%0.0f", ($phpObj->query->results->channel->item->forecast[1]->low - 32) * 5 / 9).'°C - ';
      echo ''.sprintf("%0.0f", ($phpObj->query->results->channel->item->forecast[1]->high - 32) * 5 / 9).'°C </span></li>';

      // Second Day
      echo '<li><span>'.$phpObj->query->results->channel->item->forecast[2]->day.'</span> ';
      $present_weather = str_replace(' ', '-', strtolower($phpObj->query->results->channel->item->forecast[2]->text));
      if(array_key_exists($present_weather, $weather_conditions)){
        $weather_icon = $weather_conditions[$present_weather];
      } else {
        $weather_icon = 'wi-na';
      }
      echo '<span class="wethr-temp"><i class="wi '. $weather_icon .'"></i>'.sprintf("%0.0f", ($phpObj->query->results->channel->item->forecast[2]->low - 32) * 5 / 9).'°C - ';
      echo ''.sprintf("%0.0f", ($phpObj->query->results->channel->item->forecast[2]->high - 32) * 5 / 9).'°C </span></li>';

      echo'</ul>';
    } else {
      echo '<h5 class="weather-day">'.$temp.'</h5>';
    }
    echo'</div>';

    // Display the markup after the widget
    echo $after_widget;
  }
}

// Register the widget using an annonymous function
function cascara_weather_widget_function() {
  register_widget( "cascara_weather_widget" );
}
add_action( 'widgets_init', 'cascara_weather_widget_function' );
