<?php
/**
 * Gmap - Shortcode Options
 */
add_action( 'init', 'cascara_gmap_vc_map' );
if ( ! function_exists( 'cascara_gmap_vc_map' ) ) {
  function cascara_gmap_vc_map() {
    vc_map( array(
      "name" => __( "Google Map", 'cascara-core'),
      "base" => "cscra_gmap",
      "description" => __( "Google Map Styles", 'cascara-core'),
      "icon" => "fa fa-map color-cadetblue",
      "category" => CascaraLib::cascara_cat_name(),
      "params" => array(

        array(
          "type"        => "notice",
          "heading"     => __( "API KEY", 'cascara-core' ),
          "param_name"  => 'api_key',
          'class'       => 'cs-info',
          'value'       => '',
        ),
        array(
          "type"        =>'textfield',
          "heading"     =>__('Enter Map ID', 'cascara-core'),
          "param_name"  => "gmap_id",
          "value"       => "",
          "description" => __( 'Enter google map ID. If you\'re using this in <strong>Map Tab</strong> shortcode, enter unique ID for each map tabs. Else leave it as blank. <strong>Note : This should same as Tab ID in Map Tabs shortcode.</strong>', 'cascara-core'),
          'admin_label' => true,
        ),
        array(
          "type"        =>'textfield',
          "heading"     =>__('Enter your Google Map API Key', 'cascara-core'),
          "param_name"  => "gmap_api",
          "value"       => "",
          "description" => __( 'New Google Maps usage policy dictates that everyone using the maps should register for a free API key. <br />Please create a key for "Google Static Maps API" and "Google Maps Embed API" using the <a href="https://console.developers.google.com/project" target="_blank">Google Developers Console</a>.<br /> Or follow this step links : <br /><a href="https://console.developers.google.com/flows/enableapi?apiid=maps_embed_backend&keyType=CLIENT_SIDE&reusekey=true" target="_blank">1. Step One</a> <br /><a href="https://console.developers.google.com/flows/enableapi?apiid=static_maps_backend&keyType=CLIENT_SIDE&reusekey=true" target="_blank">2. Step Two</a><br /> If you still receive errors, please check following link : <a href="https://churchthemes.com/2016/07/15/page-didnt-load-google-maps-correctly/" target="_blank">How to Fix?</a>', 'cascara-core'),
        ),

        array(
          "type"        => "notice",
          "heading"     => __( "Map Settings", 'cascara-core' ),
          "param_name"  => 'map_settings',
          'class'       => 'cs-info',
          'value'       => '',
        ),
        array(
          'type' => 'dropdown',
          'heading' => __( 'Google Map Type', 'cascara-core' ),
          'value' => array(
            __( 'Select Type', 'cascara-core' ) => '',
            __( 'ROADMAP', 'cascara-core' ) => 'ROADMAP',
            __( 'SATELLITE', 'cascara-core' ) => 'SATELLITE',
            __( 'HYBRID', 'cascara-core' ) => 'HYBRID',
            __( 'TERRAIN', 'cascara-core' ) => 'TERRAIN',
          ),
          'admin_label' => true,
          'param_name' => 'gmap_type',
          'description' => __( 'Select your google map type.', 'cascara-core' ),
        ),
        array(
          'type' => 'dropdown',
          'heading' => __( 'Google Map Style', 'cascara-core' ),
          'value' => array(
            __( 'Select Style', 'cascara-core' ) => '',
            __( 'Gray Scale', 'cascara-core' ) => "gray-scale",
            __( 'Mid Night', 'cascara-core' ) => "mid-night",
            __( 'Blue Water', 'cascara-core' ) => 'blue-water',
            __( 'Light Dream', 'cascara-core' ) => 'light-dream',
            __( 'Pale Dawn', 'cascara-core' ) => 'pale-dawn',
            __( 'Apple Maps-esque', 'cascara-core' ) => 'apple-maps',
            __( 'Blue Essence', 'cascara-core' ) => 'blue-essence',
            __( 'Unsaturated Browns', 'cascara-core' ) => 'unsaturated-browns',
            __( 'Paper', 'cascara-core' ) => 'paper',
            __( 'Midnight Commander', 'cascara-core' ) => 'midnight-commander',
            __( 'Light Monochrome', 'cascara-core' ) => 'light-monochrome',
            __( 'Flat Map', 'cascara-core' ) => 'flat-map',
            __( 'Retro', 'cascara-core' ) => 'retro',
            __( 'becomeadinosaur', 'cascara-core' ) => 'becomeadinosaur',
            __( 'Neutral Blue', 'cascara-core' ) => 'neutral-blue',
            __( 'Subtle Grayscale', 'cascara-core' ) => 'subtle-grayscale',
            __( 'Ultra Light with Labels', 'cascara-core' ) => 'ultra-light-labels',
            __( 'Shades of Grey', 'cascara-core' ) => 'shades-grey',
          ),
          'admin_label' => true,
          'param_name' => 'gmap_style',
          'description' => __( 'Select your google map style.', 'cascara-core' ),
          'dependency' => array(
            'element' => 'gmap_type',
            'value' => 'ROADMAP',
          ),
        ),
        array(
          "type"        =>'textfield',
          "heading"     =>__('Height', 'cascara-core'),
          "param_name"  => "gmap_height",
          "value"       => "",
          "description" => __( "Enter the px value for map height. This will not work if you add this shortcode into the Map Tab shortcode.", 'cascara-core'),
          'edit_field_class'   => 'vc_col-md-6 vc_column vt_field_space',
        ),
        array(
          "type"        =>'attach_image',
          "heading"     =>__('Common Marker', 'cascara-core'),
          "param_name"  => "gmap_common_marker",
          "value"       => "",
          "description" => __( "Upload your custom marker.", 'cascara-core'),
          'edit_field_class'   => 'vc_col-md-6 vc_column vt_field_space',
        ),

        array(
          "type"        => "notice",
          "heading"     => __( "Enable & Disable", 'cascara-core' ),
          "param_name"  => 'enb_disb',
          'class'       => 'cs-info',
          'value'       => '',
        ),
        array(
          "type"        =>'switcher',
          "heading"     =>__('Scroll Wheel', 'cascara-core'),
          "param_name"  => "gmap_scroll_wheel",
          "value"       => "",
          "std"         => false,
          'edit_field_class'   => 'vc_col-md-4 vc_column vt_field_space',
        ),
        array(
          "type"        =>'switcher',
          "heading"     =>__('Street View Control', 'cascara-core'),
          "param_name"  => "gmap_street_view",
          "value"       => "",
          "std"         => false,
          'edit_field_class'   => 'vc_col-md-4 vc_column vt_field_space',
        ),
        array(
          "type"        =>'switcher',
          "heading"     =>__('Map Type Control', 'cascara-core'),
          "param_name"  => "gmap_maptype_control",
          "value"       => "",
          "std"         => false,
          'edit_field_class'   => 'vc_col-md-4 vc_column vt_field_space',
        ),

        // Map Markers
        array(
          "type"        => "notice",
          "heading"     => __( "Map Pins", 'cascara-core' ),
          "param_name"  => 'map_pins',
          'class'       => 'cs-info',
          'value'       => '',
        ),
        array(
          'type' => 'param_group',
          'value' => '',
          'heading' => __( 'Map Locations', 'cascara-core' ),
          'param_name' => 'locations',
          'params' => array(

            array(
              'type' => 'textfield',
              'value' => '',
              'heading' => __( 'Latitude', 'cascara-core' ),
              'param_name' => 'latitude',
              'edit_field_class'   => 'vc_col-md-6 vc_column vt_field_space',
              'admin_label' => true,
              'description' => __( 'Find Latitude : <a href="http://www.latlong.net/" target="_blank">latlong.net</a>', 'cascara-core' ),
            ),
            array(
              'type' => 'textfield',
              'value' => '',
              'heading' => __( 'Longitude', 'cascara-core' ),
              'param_name' => 'longitude',
              'edit_field_class'   => 'vc_col-md-6 vc_column vt_field_space',
              'admin_label' => true,
              'description' => __( 'Find Longitude : <a href="http://www.latlong.net/" target="_blank">latlong.net</a>', 'cascara-core' ),
            ),
            array(
              'type' => 'attach_image',
              'value' => '',
              'heading' => __( 'Custom Marker', 'cascara-core' ),
              'param_name' => 'custom_marker',
              "description" => __( "Upload your unique map marker if your want to differentiate from others.", 'cascara-core'),
            ),
            array(
              'type' => 'textfield',
              'value' => '',
              'heading' => __( 'Heading', 'cascara-core' ),
              'param_name' => 'location_heading',
              'admin_label' => true,
            ),
            array(
              'type' => 'textarea',
              'value' => '',
              'heading' => __( 'Content', 'cascara-core' ),
              'param_name' => 'location_text',
            ),

          )
        ),

        CascaraLib::vt_class_option(),

        // Design Tab
        array(
          "type" => "css_editor",
          "heading" => __( "Text Size", 'cascara-core' ),
          "param_name" => "css",
          "group" => __( "Design", 'cascara-core'),
        ),

      )
    ) );
  }
}
