<?php
/*
 * All Theme Options for Cascara theme.
 * Author & Copyright: VictorThemes
 * URL: https://victorthemes.com/wp-themes
 */

function cascara_vt_settings( $settings ) {

  $settings           = array(
    'menu_title'      => CASCARA_NAME . esc_html__(' Options', 'cascara'),
    'menu_slug'       => sanitize_title(CASCARA_NAME) . '_options',
    'menu_type'       => 'menu',
    'menu_icon'       => 'dashicons-awards',
    'menu_position'   => '4',
    'ajax_save'       => false,
    'show_reset_all'  => true,
    'framework_title' => CASCARA_NAME .' <small>V-'. CASCARA_VERSION .' by <a href="'. CASCARA_BRAND_URL .'" target="_blank">'. CASCARA_BRAND_NAME .'</a></small>',
  );

  return $settings;

}
add_filter( 'cs_framework_settings', 'cascara_vt_settings' );

// Theme Framework Options
function cascara_vt_options( $options ) {

  $options      = array(); // remove old options

  // ------------------------------
  // Theme Brand
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_brand',
    'title'    => esc_html__('Brand', 'cascara'),
    'icon'     => 'fa fa-bookmark',
    'sections' => array(

      // brand logo tab
      array(
        'name'     => 'brand_logo_title',
        'title'    => esc_html__('Logo', 'cascara'),
        'icon'     => 'fa fa-star',
        'fields'   => array(

          // Site Logo
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Site Logo', 'cascara')
          ),
          array(
            'id'    => 'brand_logo_default',
            'type'  => 'image',
            'title' => esc_html__('Default Logo', 'cascara'),
            'info'  => esc_html__('Upload your default logo here. If you not upload, then site title will load in this logo location.', 'cascara'),
            'add_title' => esc_html__('Add Logo', 'cascara'),
          ),
          array(
            'id'    => 'brand_logo_retina',
            'type'  => 'image',
            'title' => esc_html__('Retina Logo', 'cascara'),
            'info'  => esc_html__('Upload your retina logo here. Recommended size is 2x from default logo.', 'cascara'),
            'add_title' => esc_html__('Add Retina Logo', 'cascara'),
          ),
          array(
            'id'          => 'retina_width',
            'type'        => 'text',
            'title'       => esc_html__('Retina & Normal Logo Width', 'cascara'),
            'unit'        => 'px',
          ),
          array(
            'id'          => 'retina_height',
            'type'        => 'text',
            'title'       => esc_html__('Retina & Normal Logo Height', 'cascara'),
            'unit'        => 'px',
          ),
          array(
            'id'          => 'brand_logo_top',
            'type'        => 'number',
            'title'       => esc_html__('Logo Top Space', 'cascara'),
            'attributes'  => array( 'placeholder' => 5 ),
            'unit'        => 'px',
          ),
          array(
            'id'          => 'brand_logo_bottom',
            'type'        => 'number',
            'title'       => esc_html__('Logo Bottom Space', 'cascara'),
            'attributes'  => array( 'placeholder' => 5 ),
            'unit'        => 'px',
          ),

          // WordPress Admin Logo
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('WordPress Admin Logo', 'cascara')
          ),
          array(
            'id'    => 'brand_logo_wp',
            'type'  => 'image',
            'title' => esc_html__('Login logo', 'cascara'),
            'info'  => esc_html__('Upload your WordPress login page logo here.', 'cascara'),
            'add_title' => esc_html__('Add Login Logo', 'cascara'),
          ),
        ) // end: fields
      ), // end: section

      // brand logo tab
      array(
        'name'     => 'mobile_logo_title',
        'title'    => esc_html__('Mobile Logo', 'cascara'),
        'icon'     => 'fa fa-mobile',
        'fields'   => array(

          // Mobile Logo
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Mobile Logo - If you not upload mobile logo as separatly here, then normal logo will place in that position.', 'cascara')
          ),
          array(
            'id'    => 'mobile_logo_retina',
            'type'  => 'image',
            'title' => esc_html__('Mobile Logo', 'cascara'),
            'info'  => esc_html__('Upload your mobile logo as retina size.', 'cascara'),
            'add_title' => esc_html__('Add Mobile Logo', 'cascara'),
          ),
          array(
            'id'          => 'mobile_logo_width',
            'type'        => 'text',
            'title'       => esc_html__('Mobile Logo Width', 'cascara'),
            'unit'        => 'px',
          ),
          array(
            'id'          => 'mobile_logo_height',
            'type'        => 'text',
            'title'       => esc_html__('Mobile Logo Height', 'cascara'),
            'unit'        => 'px',
          ),
          array(
            'id'          => 'mobile_logo_top',
            'type'        => 'number',
            'title'       => esc_html__('Logo Top Space', 'cascara'),
            'attributes'  => array( 'placeholder' => 5 ),
            'unit'        => 'px',
          ),
          array(
            'id'          => 'mobile_logo_bottom',
            'type'        => 'number',
            'title'       => esc_html__('Logo Bottom Space', 'cascara'),
            'attributes'  => array( 'placeholder' => 5 ),
            'unit'        => 'px',
          ),

        ) // end: fields
      ), // end: section

      // Fav
      array(
        'name'     => 'brand_fav',
        'title'    => esc_html__('Fav Icon', 'cascara'),
        'icon'     => 'fa fa-anchor',
        'fields'   => array(

            // -----------------------------
            // Begin: Fav
            // -----------------------------
            array(
              'id'    => 'brand_fav_icon',
              'type'  => 'image',
              'title' => esc_html__('Fav Icon', 'cascara'),
              'info'  => esc_html__('Upload your site fav icon, size should be 16x16.', 'cascara'),
              'add_title' => esc_html__('Add Fav Icon', 'cascara'),
            ),
            array(
              'id'    => 'iphone_icon',
              'type'  => 'image',
              'title' => esc_html__('Apple iPhone icon', 'cascara'),
              'info'  => esc_html__('Icon for Apple iPhone (57px x 57px). This icon is used for Bookmark on Home screen.', 'cascara'),
              'add_title' => esc_html__('Add iPhone Icon', 'cascara'),
            ),
            array(
              'id'    => 'iphone_retina_icon',
              'type'  => 'image',
              'title' => esc_html__('Apple iPhone retina icon', 'cascara'),
              'info'  => esc_html__('Icon for Apple iPhone retina (114px x114px). This icon is used for Bookmark on Home screen.', 'cascara'),
              'add_title' => esc_html__('Add iPhone Retina Icon', 'cascara'),
            ),
            array(
              'id'    => 'ipad_icon',
              'type'  => 'image',
              'title' => esc_html__('Apple iPad icon', 'cascara'),
              'info'  => esc_html__('Icon for Apple iPad (72px x 72px). This icon is used for Bookmark on Home screen.', 'cascara'),
              'add_title' => esc_html__('Add iPad Icon', 'cascara'),
            ),
            array(
              'id'    => 'ipad_retina_icon',
              'type'  => 'image',
              'title' => esc_html__('Apple iPad retina icon', 'cascara'),
              'info'  => esc_html__('Icon for Apple iPad retina (144px x 144px). This icon is used for Bookmark on Home screen.', 'cascara'),
              'add_title' => esc_html__('Add iPad Retina Icon', 'cascara'),
            ),

        ) // end: fields
      ), // end: section

    ),
  );

  // ------------------------------
  // Layout
  // ------------------------------
  $options[] = array(
    'name'   => 'theme_layout',
    'title'  => esc_html__('Layout', 'cascara'),
    'icon'   => 'fa fa-file-text'
  );

  $options[]      = array(
    'name'        => 'theme_general',
    'title'       => esc_html__('General', 'cascara'),
    'icon'        => 'fa fa-wrench',

    // begin: fields
    'fields'      => array(

      // -----------------------------
      // Begin: Responsive
      // -----------------------------
      array(
        'id'    => 'theme_responsive',
        'type'  => 'switcher',
        'title' => esc_html__('Responsive', 'cascara'),
        'info' => esc_html__('Turn off if you don\'t want your site to be responsive.', 'cascara'),
        'default' => true,
      ),
      array(
        'id'    => 'theme_preloader',
        'type'  => 'switcher',
        'title' => esc_html__('Preloader', 'cascara'),
        'info' => esc_html__('Turn off if you don\'t want preloader.', 'cascara'),
        'default' => false,
      ),
      array(
        'id'    => 'theme_btotop',
        'type'  => 'switcher',
        'title' => esc_html__('Back To Top', 'cascara'),
        'info' => esc_html__('Turn off if you don\'t want back to top button.', 'cascara'),
        'default' => true,
      ),
      array(
        'id'    => 'theme_lazyload',
        'type'  => 'switcher',
        'title' => esc_html__('Include Lazyload For Images?', 'cascara'),
        'info' => esc_html__('Turn off if you don\'t want lazyload.', 'cascara'),
        'default' => true,
      ),
      array(
        'id'    => 'image_link_wrap',
        'type'  => 'switcher',
        'title' => esc_html__('Need Link For Post Images?', 'cascara'),
        'info' => esc_html__('Turn on if you want link for post featured images.', 'cascara'),
      ),
      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Image Resize Options', 'cascara'),
      ),
      array(
        'id'       => 'theme_img_resizer',
        'type'     => 'switcher',
        'title'    => esc_html__( 'Disable Image Resizer?', 'cascara' ),
        'desc'     => esc_html__( 'Turn on if you don\'t want image resizer.', 'cascara' ),
        'text_on'  => 'Yes',
        'text_off' => 'No',
      ),

    ), // end: fields

  );

  // ------------------------------
  // Header Sections
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_header_tab',
    'title'    => esc_html__('Header', 'cascara'),
    'icon'     => 'fa fa-bars',
    'sections' => array(

      // header design tab
      array(
        'name'     => 'header_design_tab',
        'title'    => esc_html__('Design', 'cascara'),
        'icon'     => 'fa fa-magic',
        'fields'   => array(

          array(
            'id'             => 'sticky_header',
            'type'           => 'select',
            'title'          => esc_html__('Sticky Header', 'cascara'),
            'options'        => array(
              'sticky' => esc_html__('Sticky', 'cascara'),
              'not-sticky' => esc_html__('Not Sticky', 'cascara'),
            ),
          ),
          array(
            'id'          => 'mobile_breakpoint',
            'type'        => 'text',
            'title'       => esc_html__('Mobile Menu Starts from?', 'cascara'),
            'attributes'  => array( 'placeholder' => '991' ),
            'info' => esc_html__('Just put numeric value only. Like : 991. Don\'t use px or any other units.', 'cascara'),
          ),
          array(
            'id'        => 'login_signup_icon',
            'type'      => 'select',
            'title'     => esc_html__('Login/Signup Icon', 'cascara'),
            'options'   => array(
              'show' => 'Show',
              'hide'   => 'Hide',
            ),
          ),
          array(
            'id'          => 'login_link',
            'type'        => 'text',
            'title'       => esc_html__('Login Page Link', 'cascara'),
            'info' => esc_html__('Insert login page link here.', 'cascara'),
          ),
          array(
            'id'          => 'signup_link',
            'type'        => 'text',
            'title'       => esc_html__('Signup Page Link', 'cascara'),
            'info' => esc_html__('Insert signup page link here.', 'cascara'),
          ),

        )
      ),

      // header top bar
      array(
        'name'     => 'header_top_bar_tab',
        'title'    => esc_html__('Top Bar', 'cascara'),
        'icon'     => 'fa fa-minus',
        'fields'   => array(

          array(
            'id'          => 'top_bar',
            'type'        => 'switcher',
            'title'       => esc_html__('Hide Top Bar', 'cascara'),
            'on_text'     => esc_html__('Yes', 'cascara'),
            'off_text'    => esc_html__('No', 'cascara'),
            'default'     => false,
          ),
          array(
            'id'          => 'top_left',
            'title'       => esc_html__('Top Left Block', 'cascara'),
            'desc'        => esc_html__('Top bar left block.', 'cascara'),
            'type'        => 'textarea',
            'shortcode'   => true,
            'dependency'  => array('top_bar', '==', false),
          ),
          array(
            'id'          => 'top_right',
            'title'       => esc_html__('Top Right Block', 'cascara'),
            'desc'        => esc_html__('Top bar right block.', 'cascara'),
            'type'        => 'textarea',
            'shortcode'   => true,
            'dependency'  => array('top_bar', '==', false),
          ),
          array(
            'id'          => 'top_center',
            'title'       => esc_html__('Top Center Block', 'cascara'),
            'desc'        => esc_html__('Top bar center block.', 'cascara'),
            'type'        => 'textarea',
            'shortcode'   => true,
            'dependency'  => array('top_bar', '==', false),
          ),

          array(
            'id'          => 'topbar_left_width',
            'type'        => 'text',
            'title'       => esc_html__('Top Left Width in %', 'cascara'),
            'attributes'  => array(
              'placeholder' => '50%'
            ),
            'dependency'  => array('top_bar', '==', false),
          ),
          array(
            'id'          => 'topbar_right_width',
            'type'        => 'text',
            'title'       => esc_html__('Top Right Width in %', 'cascara'),
            'attributes'  => array(
              'placeholder' => '50%'
            ),
            'dependency'  => array('top_bar', '==', false),
          ),
          array(
            'id'          => 'topbar_center_width',
            'type'        => 'text',
            'title'       => esc_html__('Top center Width in %', 'cascara'),
            'attributes'  => array(
              'placeholder' => '50%'
            ),
            'dependency'  => array('top_bar', '==', false),
          ),

        )
      ),

      // Trending top bar
      array(
        'name'     => 'header_top_bar_trending_tab',
        'title'    => esc_html__('Trending Top Bar', 'cascara'),
        'icon'     => 'fa fa-minus',
        'fields'   => array(

          array(
            'id'          => 'trending_top_bar',
            'type'        => 'switcher',
            'title'       => esc_html__('Hide Trending Top Bar', 'cascara'),
            'on_text'     => esc_html__('Yes', 'cascara'),
            'off_text'    => esc_html__('No', 'cascara'),
            'default'     => false,
          ),
          array(
            "type"        =>'text',
            "title"     => esc_html__('Trending Title', 'cascara'),
            "id"  => "trending_title",
            "info" => esc_html__( "Enter trending now text.", 'cascara'),
            'dependency'  => array('trending_top_bar', '==', false),
          ),
          array(
            "type"        =>'text',
            "title"     => esc_html__('Limit', 'cascara'),
            "id"  => "trend_blog_limit",
            "info" => esc_html__( "Enter the number of items to show.", 'cascara'),
            'dependency'  => array('trending_top_bar', '==', false),
          ),
          array(
            'id'          => 'trend_blog_order',
            'title'       => esc_html__('Blog Order', 'cascara'),
            'desc'        => esc_html__('Select blog order', 'cascara'),
            'type'        => 'select',
            'options'        => array(
              'ASC' => esc_html__('Ascending', 'cascara'),
              'DESC' => esc_html__('Decending', 'cascara'),
            ),
            'dependency'  => array('trending_top_bar', '==', false),
          ),
          array(
            'id'          => 'trend_blog_orderby',
            'title'       => esc_html__('Blog Orderby', 'cascara'),
            'desc'        => esc_html__('Select blog orderby', 'cascara'),
            'type'        => 'select',
            'options'        => array(
              'None' => esc_html__('None', 'cascara'),
              'id' => esc_html__('ID', 'cascara'),
              'author' => esc_html__('Author', 'cascara'),
              'title' => esc_html__('Title', 'cascara'),
              'name' => esc_html__('Name', 'cascara'),
              'type' => esc_html__('Type', 'cascara'),
              'date' => esc_html__('Date', 'cascara'),
              'modified' => esc_html__('Modified', 'cascara'),
              'random' => esc_html__('Random', 'cascara'),
            ),
            'dependency'  => array('trending_top_bar', '==', false),
          ),
          array(
            "type" => "checkbox",
            "title" => esc_html__( "Show Only Category", 'cascara' ),
            "id" => "particular_cat",
            "options" => 'categories',
            "desc" => esc_html__( "Select categories to show.", 'cascara'),
            'dependency'  => array('trending_top_bar', '==', false),
          ),

        )
      ),

      // header banner
      array(
        'name'     => 'header_banner_tab',
        'title'    => esc_html__('Title Bar (or) Banner', 'cascara'),
        'icon'     => 'fa fa-bullhorn',
        'fields'   => array(

          // Title Area
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Title Area', 'cascara')
          ),
          array(
            'id'      => 'need_title_bar',
            'type'    => 'switcher',
            'title'   => esc_html__('Title Bar', 'cascara'),
            'label'   => esc_html__('If you want title bar in your sub-pages, please turn this ON.', 'cascara'),
            'default'    => true,
          ),
          array(
            'id'             => 'title_bar_padding',
            'type'           => 'select',
            'title'          => esc_html__('Padding Spaces Top & Bottom', 'cascara'),
            'options'        => array(
              'padding-none' => esc_html__('Default Spacing', 'cascara'),
              'padding-xs' => esc_html__('Extra Small Padding', 'cascara'),
              'padding-sm' => esc_html__('Small Padding', 'cascara'),
              'padding-md' => esc_html__('Medium Padding', 'cascara'),
              'padding-lg' => esc_html__('Large Padding', 'cascara'),
              'padding-xl' => esc_html__('Extra Large Padding', 'cascara'),
              'padding-no' => esc_html__('No Padding', 'cascara'),
              'padding-custom' => esc_html__('Custom Padding', 'cascara'),
            ),
            'dependency'   => array( 'need_title_bar', '==', 'true' ),
          ),
          array(
            'id'             => 'titlebar_top_padding',
            'type'           => 'text',
            'title'          => esc_html__('Padding Top', 'cascara'),
            'attributes' => array(
              'placeholder'     => '100px',
            ),
            'dependency'   => array( 'title_bar_padding', '==', 'padding-custom' ),
          ),
          array(
            'id'             => 'titlebar_bottom_padding',
            'type'           => 'text',
            'title'          => esc_html__('Padding Bottom', 'cascara'),
            'attributes' => array(
              'placeholder'     => '100px',
            ),
            'dependency'   => array( 'title_bar_padding', '==', 'padding-custom' ),
          ),

          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Background Options', 'cascara'),
            'dependency' => array( 'need_title_bar', '==', 'true' ),
          ),
          array(
            'id'      => 'titlebar_bg_overlay_color',
            'type'    => 'color_picker',
            'title'   => esc_html__('Background Color', 'cascara'),
            'dependency' => array( 'need_title_bar', '==', 'true' ),
          ),

        )
      ),

      // Side Bar Menu
      array(
        'name'     => 'header_sidebar_menu_tab',
        'title'    => esc_html__('Side Bar Menu', 'cascara'),
        'icon'     => 'fa fa-minus',
        'fields'   => array(

          array(
            'id'             => 'fixed_navigation',
            'type'           => 'select',
            'title'          => esc_html__('Fixed Navigation', 'cascara'),
            'options'        => array(
              'hide' => esc_html__('Hide', 'cascara'),
              'show' => esc_html__('Show', 'cascara'),
            ),
          ),
          array(
            'id'          => 'side_menu_style',
            'title'       => esc_html__('Select Side Menu', 'cascara'),
            'type'        => 'select',
            'options'        => array(
              'default' => esc_html__('Default Menu', 'cascara'),
              'custom' => esc_html__('Custom Menu', 'cascara'),
            ),
            'dependency'  => array('fixed_navigation', '==', 'show'),
          ),
          array(
            'id'             => 'choose_menu',
            'type'           => 'select',
            'title'          => esc_html__('Choose Menu', 'cascara'),
            'desc'          => esc_html__('Choose custom menus for this page.', 'cascara'),
            'options'        => 'menus',
            'default_option' => esc_html__('Select your menu', 'cascara'),
            'dependency'  => array('side_menu_style|fixed_navigation', '==|==', 'default|show'),
          ),

          array(
            "type"        =>'textarea',
            "title"     => esc_html__('Custom Menu Shortcode', 'cascara'),
            "id"  => "custom_menu",
            'shortcode'   => true,
            "info" => esc_html__( "Include custom shortcode to display in side menu section.", 'cascara'),
            'dependency'  => array('side_menu_style|fixed_navigation', '==|==', 'custom|show'),
          ),
          array(
            "type"        =>'textarea',
            "title"     => esc_html__('Subscribe Shortcode', 'cascara'),
            "id"  => "subscribe",
            'shortcode'   => true,
            "info" => esc_html__( "Include subscribe shortcode to display in side menu section.", 'cascara'),
            'dependency'  => array('fixed_navigation', '==', 'show'),
          ),
          array(
            "type"        =>'textarea',
            "title"     => esc_html__('Social Shortcode', 'cascara'),
            "id"  => "social_shortcode",
            'shortcode'   => true,
            "info" => esc_html__( "Include social shortcode to display in side menu section.", 'cascara'),
            'dependency'  => array('fixed_navigation', '==', 'show'),
          ),

        )
      ),
      // Search Popup
      array(
        'name'     => 'header_search_popup_tab',
        'title'    => esc_html__('Search Popup', 'cascara'),
        'icon'     => 'fa fa-minus',
        'fields'   => array(

          array(
            'id'             => 'search_icon',
            'type'           => 'select',
            'title'          => esc_html__('Search Icon', 'cascara'),
            'options'        => array(
              'hide' => esc_html__('Hide', 'cascara'),
              'show' => esc_html__('Show', 'cascara'),
            ),
          ),
          array(
            'id'             => 'back_text',
            'type'           => 'text',
            'title'          => esc_html__('Back Text', 'cascara'),
            'dependency'   => array( 'search_icon', '==', 'show' ),
          ),
          array(
            'id'             => 'search_enter_text',
            'type'           => 'text',
            'title'          => esc_html__('Search & Enter Text', 'cascara'),
            'dependency'   => array( 'search_icon', '==', 'show' ),
          ),
          array(
            'id'             => 'search_placeholder_text',
            'type'           => 'text',
            'title'          => esc_html__('Search Placeholder', 'cascara'),
            'attributes' => array(
              'placeholder'     => 'Start Searching',
            ),
            'dependency'   => array( 'search_icon', '==', 'show' ),
          ),
          array(
            'id'    => 'recent_post',
            'type'  => 'switcher',
            'title' => esc_html__('Hide Recent Posts', 'cascara'),
            'default' => false,
            'dependency'   => array( 'search_icon', '==', 'show' ),
          ),
          array(
            "type"        =>'text',
            "title"     => esc_html__('Recent Post Title', 'cascara'),
            "id"  => "recent_post_title",
            "info" => esc_html__( "Enter recent post title.", 'cascara'),
            'dependency'  => array('recent_post|search_icon', '==|==', 'false|show'),
          ),
          array(
            'id'             => 'recent_post_column',
            'type'           => 'select',
            'title'          => esc_html__('Recent Post Column', 'cascara'),
            'options'        => array(
              'col-md-6' => esc_html__('Two Column', 'cascara'),
              'col-md-4' => esc_html__('Three Column', 'cascara'),
              'col-md-3' => esc_html__('Four Column', 'cascara'),
            ),
            'dependency'  => array('recent_post|search_icon', '==|==', 'false|show'),
          ),
          array(
            "type"        =>'text',
            "title"     => esc_html__('Limit', 'cascara'),
            "id"  => "search_blog_limit",
            "info" => esc_html__( "Enter the number of items to show.", 'cascara'),
            'dependency'  => array('recent_post|search_icon', '==|==', 'false|show'),
          ),
          array(
            'id'          => 'search_blog_order',
            'title'       => esc_html__('Blog Order', 'cascara'),
            'desc'        => esc_html__('Select blog order', 'cascara'),
            'type'        => 'select',
            'options'        => array(
              'ASC' => esc_html__('Ascending', 'cascara'),
              'DESC' => esc_html__('Decending', 'cascara'),
            ),
            'dependency'  => array('recent_post|search_icon', '==|==', 'false|show'),
          ),
          array(
            'id'          => 'search_blog_orderby',
            'title'       => esc_html__('Blog Orderby', 'cascara'),
            'desc'        => esc_html__('Select blog orderby', 'cascara'),
            'type'        => 'select',
            'options'        => array(
              'None' => esc_html__('None', 'cascara'),
              'id' => esc_html__('ID', 'cascara'),
              'author' => esc_html__('Author', 'cascara'),
              'title' => esc_html__('Title', 'cascara'),
              'name' => esc_html__('Name', 'cascara'),
              'type' => esc_html__('Type', 'cascara'),
              'date' => esc_html__('Date', 'cascara'),
              'modified' => esc_html__('Modified', 'cascara'),
              'random' => esc_html__('Random', 'cascara'),
            ),
            'dependency'  => array('recent_post|search_icon', '==|==', 'false|show'),
          ),
          array(
            "type" => "checkbox",
            "title" => esc_html__( "Show Only Category", 'cascara' ),
            "id" => "search_particular_cat",
            "options" => 'categories',
            "desc" => esc_html__( "Select categories to show.", 'cascara'),
            'dependency'  => array('recent_post|search_icon', '==|==', 'false|show'),
          ),
        )
      ),

    ),
  );

  // ------------------------------
  // Footer Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'footer_section',
    'title'    => esc_html__('Footer', 'cascara'),
    'icon'     => 'fa fa-ellipsis-h',
    'sections' => array(

      // footer widgets
      array(
        'name'     => 'footer_widgets_tab',
        'title'    => esc_html__('Widget Area', 'cascara'),
        'icon'     => 'fa fa-th',
        'fields'   => array(

          // Footer Widget Block
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Footer Widget Block', 'cascara')
          ),
          array(
            'id'    => 'footer_widget_block',
            'type'  => 'switcher',
            'title' => esc_html__('Enable Widget Block', 'cascara'),
            'info' => esc_html__('If you turn this ON, then Goto : Appearance > Widgets. There you can see <strong>Footer Widget 1,2,3 or 4</strong> Widget Area, add your widgets there.', 'cascara'),
            'default' => true,
          ),
          array(
            'id'             => 'sticky_footer',
            'type'           => 'select',
            'title'          => esc_html__('Sticky Footer', 'cascara'),
            'options'        => array(
              'not-sticky' => esc_html__('Not Sticky', 'cascara'),
              'sticky' => esc_html__('Sticky', 'cascara'),
            ),
          ),
          array(
            'id'    => 'footer_widget_layout',
            'type'  => 'image_select',
            'title' => esc_html__('Widget Layouts', 'cascara'),
            'info' => esc_html__('Choose your footer widget layouts.', 'cascara'),
            'default' => 10,
            'options' => array(
              1   => CASCARA_CS_IMAGES . '/footer/footer-1.png',
              2   => CASCARA_CS_IMAGES . '/footer/footer-2.png',
              3   => CASCARA_CS_IMAGES . '/footer/footer-3.png',
              4   => CASCARA_CS_IMAGES . '/footer/footer-4.png',
              5   => CASCARA_CS_IMAGES . '/footer/footer-5.png',
              6   => CASCARA_CS_IMAGES . '/footer/footer-6.png',
              7   => CASCARA_CS_IMAGES . '/footer/footer-7.png',
              8   => CASCARA_CS_IMAGES . '/footer/footer-8.png',
              9   => CASCARA_CS_IMAGES . '/footer/footer-9.png',
              10   => CASCARA_CS_IMAGES . '/footer/footer-10.png',
            ),
            'radio'       => true,
            'dependency'  => array('footer_widget_block', '==', true),
          ),

        )
      ),

      // footer copyright
      array(
        'name'     => 'footer_copyright_tab',
        'title'    => esc_html__('Copyright Bar', 'cascara'),
        'icon'     => 'fa fa-copyright',
        'fields'   => array(

          // Copyright
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Copyright Layout', 'cascara'),
          ),
          array(
            'id'    => 'need_copyright',
            'type'  => 'switcher',
            'title' => esc_html__('Enable Copyright Section', 'cascara'),
            'default' => true,
          ),
          array(
            'id'    => 'footer_copyright_layout',
            'type'  => 'image_select',
            'title' => esc_html__('Select Copyright Layout', 'cascara'),
            'info' => esc_html__('In above image, blue box is copyright text and yellow box is secondary text.', 'cascara'),
            'default'      => 'copyright-3',
            'options'      => array(
              'copyright-1'    => CASCARA_CS_IMAGES .'/footer/copyright-1.png',
              'copyright-2'    => CASCARA_CS_IMAGES .'/footer/copyright-2.png',
              'copyright-3'    => CASCARA_CS_IMAGES .'/footer/copyright-3.png',
              ),
            'radio'        => true,
            'dependency'     => array('need_copyright', '==', true),
          ),
          array(
            'id'    => 'copyright_text',
            'type'  => 'textarea',
            'title' => esc_html__('Copyright Text', 'cascara'),
            'shortcode' => true,
            'dependency' => array('need_copyright', '==', true),
            'after'       => 'Helpful shortcodes: [cascara_current_year] [cascara_home_url] or any shortcode.',
          ),

          // Copyright Another Text
          array(
            'type'    => 'notice',
            'class'   => 'warning cs-vt-heading',
            'content' => esc_html__('Copyright Secondary Text', 'cascara'),
            'dependency'     => array('need_copyright', '==', 'true'),
          ),
          array(
            'id'    => 'secondary_text',
            'type'  => 'textarea',
            'title' => esc_html__('Secondary Text', 'cascara'),
            'shortcode' => true,
            'dependency'     => array('need_copyright', '==', 'true'),
          ),

        )
      ),

    ),
  );

  // ------------------------------
  // Design
  // ------------------------------
  $options[] = array(
    'name'   => 'theme_design',
    'title'  => esc_html__('Design', 'cascara'),
    'icon'   => 'fa fa-magic'
  );

  // ------------------------------
  // color section
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_color_section',
    'title'    => esc_html__('Colors', 'cascara'),
    'icon'     => 'fa fa-eyedropper',
    'fields' => array(

      array(
        'type'    => 'heading',
        'content' => esc_html__('Color Options', 'cascara'),
      ),
      array(
        'type'    => 'subheading',
        'wrap_class' => 'color-tab-content',
        'content' => esc_html__('All color options are available in our theme customizer. The reason of we used customizer options for color section is because, you can choose each part of color from there and see the changes instantly using customizer.
          <br /><br />Highly customizable colors are in <strong>Appearance > Customize</strong>', 'cascara'),
      ),

    ),
  );

  // ------------------------------
  // Typography section
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_typo_section',
    'title'    => esc_html__('Typography', 'cascara'),
    'icon'     => 'fa fa-header',
    'fields' => array(

      // Start fields
      array(
        'id'                  => 'typography',
        'type'                => 'group',
        'fields'              => array(
          array(
            'id'              => 'title',
            'type'            => 'text',
            'title'           => esc_html__('Title', 'cascara'),
          ),
          array(
            'id'              => 'selector',
            'type'            => 'textarea',
            'title'           => esc_html__('Selector', 'cascara'),
            'info'           => esc_html__('Enter css selectors like : <strong>body, .custom-class</strong>', 'cascara'),
          ),
          array(
            'id'              => 'font',
            'type'            => 'typography',
            'title'           => esc_html__('Font Family', 'cascara'),
          ),
          array(
            'id'              => 'css',
            'type'            => 'textarea',
            'title'           => esc_html__('Custom CSS', 'cascara'),
          ),
        ),
        'button_title'        => esc_html__('Add New Typography', 'cascara'),
        'accordion_title'     => esc_html__('New Typography', 'cascara'),
        'default'             => array(
          array(
            'title'           => esc_html__('Body Typography', 'cascara'),
            'selector'        => 'body, input[type="submit"], button[type="submit"], .cscra-btn, li.edition-has-dropdown.sub',
            'font'            => array(
              'family'        => 'Montserrat',
              'variant'       => 'regular',
            ),
          ),
          array(
            'title'           => esc_html__('Menu Typography', 'cascara'),
            'selector'        => '.cscra-navigation > ul > li > a',
            'font'            => array(
              'family'        => 'Poppins',
              'variant'       => 'regular',
            ),
            'size'            => '13px',
          ),
          array(
            'title'           => esc_html__('Sub Menu Typography', 'cascara'),
            'selector'        => '.cscra-navigation .dropdown-nav',
            'font'            => array(
              'family'        => 'Poppins',
              'variant'       => 'regular',
            ),
            'size'            => '12px',
            'line_height'     => '1.42857143',
          ),
          array(
            'title'           => esc_html__('Headings Typography', 'cascara'),
            'selector'        => 'h1, h2, h3, h4, h5, h6, .text-logo, .cscra-widget .posts-title',
            'font'            => array(
              'family'        => 'Montserrat',
              'variant'       => 'regular',
            ),
          ),
          array(
            'title'           => esc_html__('Shortcode Elements Font', 'cascara'),
            'selector'        => 'input[type="text"], input[type="email"], input[type="password"], input[type="tel"], input[type="search"], input[type="date"], input[type="time"], input[type="datetime-local"], input[type="month"], input[type="url"], input[type="number"], textarea, select, .form-control, p, .cscra-topbar ul, .post-meta ul, .post-category, .posts-title .view-all, .advertisement-title, .cscra-widget ul, .tweet-date, .masonry-filters, .cscra-copyright, .bullet-list, .cscra-blog-tags ul, .post-control, .cscra-comments-area .cscra-comments-meta .comments-date, .tp_recent_tweets li',
            'font'            => array(
              'family'        => 'Lato',
              'variant'       => 'regular',
            ),
          ),
          array(
            'title'           => esc_html__('Example Usage', 'cascara'),
            'selector'        => '.your-custom-class',
            'font'            => array(
              'family'        => 'Lato',
              'variant'       => 'regular',
            ),
          ),
        ),
      ),

      // Subset
      array(
        'id'                  => 'subsets',
        'type'                => 'select',
        'title'               => esc_html__('Subsets', 'cascara'),
        'class'               => 'chosen',
        'options'             => array(
          'latin'             => 'latin',
          'latin-ext'         => 'latin-ext',
          'cyrillic'          => 'cyrillic',
          'cyrillic-ext'      => 'cyrillic-ext',
          'greek'             => 'greek',
          'greek-ext'         => 'greek-ext',
          'vietnamese'        => 'vietnamese',
          'devanagari'        => 'devanagari',
          'khmer'             => 'khmer',
        ),
        'attributes'         => array(
          'data-placeholder' => 'Subsets',
          'multiple'         => 'multiple',
          'style'            => 'width: 200px;'
        ),
        'default'             => array( 'latin' ),
      ),

      array(
        'id'                  => 'font_weight',
        'type'                => 'select',
        'title'               => esc_html__('Font Weights', 'cascara'),
        'class'               => 'chosen',
        'options'             => array(
          '100'   => 'Thin 100',
          '100i'  => 'Thin 100 Italic',
          '200'   => 'Extra Light 200',
          '200i'  => 'Extra Light 200 Italic',
          '300'   => 'Light 300',
          '300i'  => 'Light 300 Italic',
          '400'   => 'Regular 400',
          '400i'  => 'Regular 400 Italic',
          '500'   => 'Medium 500',
          '500i'  => 'Medium 500 Italic',
          '600'   => 'Semi Bold 600',
          '600i'  => 'Semi Bold 600 Italic',
          '700'   => 'Bold 700',
          '700i'  => 'Bold 700 Italic',
          '800'   => 'Extra Bold 800',
          '800i'  => 'Extra Bold 800 Italic',
          '900'   => 'Black 900',
          '900i'  => 'Black 900 Italic',
        ),
        'attributes'         => array(
          'data-placeholder' => 'Font Weight',
          'multiple'         => 'multiple',
          'style'            => 'width: 200px;'
        ),
        'default'             => array( '100', '100i', '200', '200i', '300', '300i', '400', '400i', '500', '500i', '600', '600i', '700', '700i', '800', '800i', '900', '900i' ),
      ),

      // Custom Fonts Upload
      array(
        'id'                 => 'font_family',
        'type'               => 'group',
        'title'              => 'Upload Custom Fonts',
        'button_title'       => 'Add New Custom Font',
        'accordion_title'    => 'Adding New Font',
        'accordion'          => true,
        'desc'               => 'It is simple. Only add your custom fonts and click to save. After you can check "Font Family" selector. Do not forget to Save!',
        'fields'             => array(

          array(
            'id'             => 'name',
            'type'           => 'text',
            'title'          => 'Font-Family Name',
            'attributes'     => array(
              'placeholder'  => 'for eg. Arial'
            ),
          ),

          array(
            'id'             => 'ttf',
            'type'           => 'upload',
            'title'          => 'Upload .ttf <small><i>(optional)</i></small>',
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => 'Use this Font-Format',
              'button_title' => 'Upload <i>.ttf</i>',
            ),
          ),

          array(
            'id'             => 'eot',
            'type'           => 'upload',
            'title'          => 'Upload .eot <small><i>(optional)</i></small>',
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => 'Use this Font-Format',
              'button_title' => 'Upload <i>.eot</i>',
            ),
          ),

          array(
            'id'             => 'svg',
            'type'           => 'upload',
            'title'          => 'Upload .svg <small><i>(optional)</i></small>',
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => 'Use this Font-Format',
              'button_title' => 'Upload <i>.svg</i>',
            ),
          ),

          array(
            'id'             => 'otf',
            'type'           => 'upload',
            'title'          => 'Upload .otf <small><i>(optional)</i></small>',
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => 'Use this Font-Format',
              'button_title' => 'Upload <i>.otf</i>',
            ),
          ),

          array(
            'id'             => 'woff',
            'type'           => 'upload',
            'title'          => 'Upload .woff <small><i>(optional)</i></small>',
            'settings'       => array(
              'upload_type'  => 'font',
              'insert_title' => 'Use this Font-Format',
              'button_title' => 'Upload <i>.woff</i>',
            ),
          ),

          array(
            'id'             => 'css',
            'type'           => 'textarea',
            'title'          => 'Extra CSS Style <small><i>(optional)</i></small>',
            'attributes'     => array(
              'placeholder'  => 'for eg. font-weight: normal;'
            ),
          ),

        ),
      ),
      // End All field

    ),
  );

  // ------------------------------
  // Pages
  // ------------------------------
  $options[] = array(
    'name'   => 'theme_pages',
    'title'  => esc_html__('Pages', 'cascara'),
    'icon'   => 'fa fa-files-o'
  );

  // ------------------------------
  // Team Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'team_section',
    'title'    => esc_html__('Team', 'cascara'),
    'icon'     => 'fa fa-users',
    'fields' => array(

      // Team name change
      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Name Change', 'cascara')
      ),
      array(
        'id'      => 'theme_team_name',
        'type'    => 'text',
        'title'   => esc_html__('Team Name', 'cascara'),
        'attributes'     => array(
          'placeholder'  => 'Team'
        ),
      ),
      array(
        'id'      => 'theme_team_slug',
        'type'    => 'text',
        'title'   => esc_html__('Team Slug', 'cascara'),
        'attributes'     => array(
          'placeholder'  => 'team-item'
        ),
      ),
      array(
        'type'    => 'notice',
        'class'   => 'danger',
        'content' => esc_html__('<strong>Important</strong>: Please do not set team slug and page slug as same. It\'ll not work.', 'cascara')
      ),
      // Team Name

      // Team Start
      array(
        'type'    => 'notice',
        'class'   => 'info cs-vt-heading',
        'content' => esc_html__('Team Options', 'cascara')
      ),
      array(
        'id'      => 'team_limit',
        'type'    => 'text',
        'title'   => esc_html__('Team Limit', 'cascara'),
        'attributes'     => array(
          'placeholder'  => '4'
        ),
      ),
      array(
        'id'             => 'team_orderby',
        'type'           => 'select',
        'title'          => esc_html__('Order By', 'cascara'),
        'options'        => array(
          'none' => esc_html__('None', 'cascara'),
          'ID' => esc_html__('ID', 'cascara'),
          'author' => esc_html__('Author', 'cascara'),
          'title' => esc_html__('Title', 'cascara'),
          'date' => esc_html__('Date', 'cascara'),
        ),
        'default_option'     => esc_html__('Select Team Order By', 'cascara'),
      ),
      array(
        'id'             => 'team_order',
        'type'           => 'select',
        'title'          => esc_html__('Order', 'cascara'),
        'options'        => array(
          'ASC' => esc_html__('Asending', 'cascara'),
          'DESC' => esc_html__('Desending', 'cascara'),
        ),
        'default_option'     => esc_html__('Select Team Order', 'cascara'),
      ),
      // Team End

    ),
  );

  // ------------------------------
  // Blog Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'blog_section',
    'title'    => esc_html__('Blog', 'cascara'),
    'icon'     => 'fa fa-edit',
    'sections' => array(

      // blog general section
      array(
        'name'     => 'blog_general_tab',
        'title'    => esc_html__('General', 'cascara'),
        'icon'     => 'fa fa-cog',
        'fields'   => array(

          // Layout
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Layout', 'cascara')
          ),
          array(
            'id'             => 'blog_listing_style',
            'type'           => 'select',
            'title'          => esc_html__('Blog Listing Style', 'cascara'),
            'options'        => array(
              'style-one'   => esc_html__('Style One (Default)', 'cascara'),
              'style-two'   => esc_html__('Style Two (Grid\'s)', 'cascara'),
              'style-three' => esc_html__('Style Three (Grid\'s)', 'cascara'),
              'style-four'  => esc_html__('Style Four (Grid + List)', 'cascara'),
              'style-five'  => esc_html__('Style Five (List)', 'cascara'),
              'style-six'  => esc_html__('Style Six (Grid/1-column/2-Column & List)', 'cascara'),
              'style-seven'  => esc_html__('Style Seven (Grid/1-column/2-Column & 3-Column)', 'cascara'),
            ),
            // 'default_option' => 'Select blog style',
            'help'          => esc_html__('This style will apply, default blog pages - Like : Archive, Category, Tags, Search & Author. If this settings will not apply your blog page, please set that page as a post page in Settings > Readings.', 'cascara'),
          ),
          array(
            'id'             => 'blog_listing_column',
            'type'           => 'select',
            'title'          => esc_html__('Blog Listing Column', 'cascara'),
            'options'        => array(
              'col-one'   => esc_html__('Column One', 'cascara'),
              'col-two'   => esc_html__('Column Two', 'cascara'),
            ),
            'dependency'     => array('blog_listing_style', '==', 'style-one'),
          ),
          array(
            'id'             => 'primary_layout_count',
            'type'           => 'text',
            'title'          => esc_html__('Primary Layout Count', 'cascara'),
            'dependency'     => array('blog_listing_style', '==', 'style-four'),
            'info'           => esc_html__('Enter how many post item have to show in primary layout','cascara'),
          ),
          array(
            'id'             => 'one_column_count',
            'type'           => 'text',
            'title'          => esc_html__('One Column Posts Count', 'cascara'),
            'dependency'     => array('blog_listing_style', '==', 'style-seven'),
            'info'           => esc_html__('Enter how many post item have to show in one column','cascara'),
          ),
          array(
            'id'             => 'two_column_count',
            'type'           => 'text',
            'title'          => esc_html__('Two Column Posts Count', 'cascara'),
            'dependency'     => array('blog_listing_style', '==', 'style-seven'),
            'info'           => esc_html__('Enter how many post item have to show in two column','cascara'),
          ),
          array(
            'id'             => 'blog_sidebar_position',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Position', 'cascara'),
            'options'        => array(
              'sidebar-right' => esc_html__('Right', 'cascara'),
              'sidebar-left' => esc_html__('Left', 'cascara'),
              'sidebar-hide' => esc_html__('Hide', 'cascara'),
            ),
            'default_option' => 'Select sidebar position',
            'help'          => esc_html__('This style will apply, default blog pages - Like : Archive, Category, Tags, Search & Author.', 'cascara'),
            'info'          => esc_html__('Default option : Right', 'cascara'),
          ),
          array(
            'id'             => 'blog_widget',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Widget', 'cascara'),
            'options'        => cascara_vt_registered_sidebars(),
            'default_option' => esc_html__('Select Widget', 'cascara'),
            'dependency'     => array('blog_sidebar_position', '!=', 'sidebar-hide'),
            'info'          => esc_html__('Default option : Main Widget Area', 'cascara'),
          ),
          array(
            'id'             => 'sidebar_type',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Style', 'cascara'),
            'options'        => array(
              'normal'       => esc_html__('Normal', 'cascara'),
              'bar-sticky'   => esc_html__('Sticky', 'cascara'),
              'bar-float'    => esc_html__('Floating', 'cascara'),
            ),
            'default_option' => 'Select Sidebar Style',
            'dependency'     => array('blog_sidebar_position', '!=', 'sidebar-hide'),
          ),
          // Layout
          // Global Options
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Global Options', 'cascara')
          ),
          array(
            'id'         => 'theme_exclude_categories',
            'type'       => 'checkbox',
            'title'      => esc_html__('Exclude Categories', 'cascara'),
            'info'      => esc_html__('Select categories you want to exclude from blog page.', 'cascara'),
            'options'    => 'categories',
          ),
          array(
            'id'      => 'theme_blog_excerpt',
            'type'    => 'text',
            'title'   => esc_html__('Excerpt Length', 'cascara'),
            'info'   => esc_html__('Blog short content length, in blog listing pages.', 'cascara'),
            'default' => '35',
          ),
          array(
            'id'      => 'blog_pagination_style',
            'type'    => 'select',
            'title'   => esc_html__('Blog Pagination', 'cascara'),
            'options'        => array(
              'navigation' => esc_html__('Navigation', 'cascara'),
              'load-more' => esc_html__('Ajax Button', 'cascara'),
              'infinite-scroll' => esc_html__('Ajax Infinite Scroll', 'cascara'),
            ),
            'info'          => esc_html__('Default : Navigation', 'cascara'),
          ),
          array(
            'id'      => 'blog_load_btn_type',
            'type'    => 'select',
            'title'   => esc_html__('Load More Button Type', 'cascara'),
            'options'        => array(
              'button' => esc_html__('Button', 'cascara'),
              'icon' => esc_html__('Icon', 'cascara'),
            ),
            'dependency'     => array('blog_pagination_style', '==', 'load-more'),
            'info'          => esc_html__('Default : Button', 'cascara'),
          ),
          array(
            'id'        => 'blog_loader_icon_option',
            'type'      => 'select',
            'options'   => array(
              'ball-scale-multiple'         => esc_html__('Ball Scale Multiple', 'cascara'),
              'ball-pulse'                  => esc_html__('Ball Pulse', 'cascara'),
              'ball-grid-pulse'             => esc_html__('Ball Grid Pulse', 'cascara'),
              'ball-clip-rotate'            => esc_html__('Ball Clip Rotate', 'cascara'),
              'ball-clip-rotate-pulse'      => esc_html__('Ball Clip Rotate Pulse', 'cascara'),
              'square-spin'                 => esc_html__('Square Spin', 'cascara'),
              'ball-clip-rotate-multiple'   => esc_html__('Ball Clip Rotate Multiple', 'cascara'),
              'ball-pulse-rise'             => esc_html__('Ball Pulse Rise', 'cascara'),
              'ball-rotate'                 => esc_html__('Ball Rotate', 'cascara'),
              'cube-transition'             => esc_html__('Cube Transition', 'cascara'),
              'ball-zig-zag'                => esc_html__('Ball Zig Zag', 'cascara'),
              'ball-zig-zag-deflect'        => esc_html__('Ball Zig Zag Deflect', 'cascara'),
              'ball-triangle-path'          => esc_html__('Ball Triangle Path', 'cascara'),
              'ball-scale'                  => esc_html__('Ball Scale', 'cascara'),
              'line-scale'                  => esc_html__('Line Scale', 'cascara'),
              'line-scale-party'            => esc_html__('Line Scale Party', 'cascara'),
              'ball-pulse-sync'             => esc_html__('Ball Pulse Sync', 'cascara'),
              'ball-beat'                   => esc_html__('Ball Beat', 'cascara'),
              'line-scale-pulse-out'        => esc_html__('Line Scale Pulse Out', 'cascara'),
              'line-scale-pulse-out-rapid'  => esc_html__('Line Scale Pulse Out Rapid', 'cascara'),
              'ball-scale-ripple'           => esc_html__('Ball Scale Ripple', 'cascara'),
              'ball-scale-ripple-multiple'  => esc_html__('Ball Scale Ripple Multiple', 'cascara'),
              'ball-spin-fade-loader'       => esc_html__('Ball Spin Fade Loader', 'cascara'),
              'line-spin-fade-loader'       => esc_html__('Line Spin Fade Loader', 'cascara'),
              'triangle-skew-spin'          => esc_html__('Triangle Skew Spin', 'cascara'),
              'pacman'                      => esc_html__('Pacman', 'cascara'),
              'ball-grid-beat'              => esc_html__('Ball Grid Beat', 'cascara'),
              'semi-circle-spin'            => esc_html__('Semi Circle Spin', 'cascara'),
            ),
            'dependency'     => array('blog_pagination_style', '==', 'infinite-scroll'),
            'title'     => esc_html__('Loader Icon Style', 'cascara'),
          ),
          array(
            'id'      => 'blog_load_more_btn_txt',
            'type'    => 'text',
            'title'   => esc_html__('Load More Button Text', 'cascara'),
            'dependency'     => array('blog_pagination_style|blog_load_btn_type', '==|==', 'load-more|button'),
          ),
          array(
            'id'      => 'theme_metas_hide',
            'type'    => 'checkbox',
            'title'   => esc_html__('Meta\'s to hide', 'cascara'),
            'info'    => esc_html__('Check items you want to hide from blog/post meta field.', 'cascara'),
            'class'      => 'horizontal',
            'options'    => array(
              'category'   => esc_html__('Category', 'cascara'),
              'date'    => esc_html__('Date', 'cascara'),
              'author'     => esc_html__('Author', 'cascara'),
              'comments'      => esc_html__('Comments', 'cascara'),
              'views'      => esc_html__('Views', 'cascara'),
            ),
            // 'default' => '30',
          ),
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Promotion Banners', 'cascara')
          ),
          array(
            'id'    => 'promotion_image_top',
            'type'  => 'image',
            'title' => esc_html__('Promotion Banner Image(Top)', 'cascara'),
            'info'  => esc_html__('Upload your promotion image here (It will display in the top of blog global pages)', 'cascara'),
            'add_title' => esc_html__('Add Image', 'cascara'),
          ),
          array(
            'id'      => 'promotion_image_link',
            'type'    => 'text',
            'title'   => esc_html__('Promotion Image Link(Top)', 'cascara'),
          ),
          array(
            'id'    => 'promotion_image_bottom',
            'type'  => 'image',
            'title' => esc_html__('Promotion Banner Image(Bottom)', 'cascara'),
            'info'  => esc_html__('Upload your promotion image here (It will display in the bottom of blog global pages)', 'cascara'),
            'add_title' => esc_html__('Add Image', 'cascara'),
          ),
          array(
            'id'      => 'promotion_image_link_bottom',
            'type'    => 'text',
            'title'   => esc_html__('Promotion Image Link(Bottom)', 'cascara'),
          ),
          // End fields

        )
      ),

      // blog single section
      array(
        'name'     => 'blog_single_tab',
        'title'    => esc_html__('Single', 'cascara'),
        'icon'     => 'fa fa-sticky-note',
        'fields'   => array(

          // Start fields
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Enable / Disable', 'cascara')
          ),
          array(
            'id'    => 'single_featured_image',
            'type'  => 'switcher',
            'title' => esc_html__('Featured Image', 'cascara'),
            'info' => esc_html__('If need to hide featured image from single blog post page, please turn this OFF.', 'cascara'),
            'default' => true,
          ),
          array(
            'id'    => 'single_share_option',
            'type'  => 'switcher',
            'title' => esc_html__('Share Option', 'cascara'),
            'info' => esc_html__('If need to hide share option on single blog page, please turn this OFF.', 'cascara'),
            'default' => true,
          ),
          array(
            'id'    => 'single_author_info',
            'type'  => 'switcher',
            'title' => esc_html__('Author Info', 'cascara'),
            'info' => esc_html__('If need to hide author info on single blog page, please turn this OFF.', 'cascara'),
            'default' => true,
          ),

          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Sidebar', 'cascara')
          ),
          array(
            'id'             => 'single_sidebar_position',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Position', 'cascara'),
            'options'        => array(
              'sidebar-right' => esc_html__('Right', 'cascara'),
              'sidebar-left' => esc_html__('Left', 'cascara'),
              'sidebar-hide' => esc_html__('Hide', 'cascara'),
            ),
            'default_option' => 'Select sidebar position',
            'info'          => esc_html__('Default option : Right', 'cascara'),
          ),
          array(
            'id'             => 'single_blog_widget',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Widget', 'cascara'),
            'options'        => cascara_vt_registered_sidebars(),
            'default_option' => esc_html__('Select Widget', 'cascara'),
            'dependency'     => array('single_sidebar_position', '!=', 'sidebar-hide'),
            'info'          => esc_html__('Default option : Main Widget Area', 'cascara'),
          ),
          array(
            'id'             => 'single_sidebar_type',
            'type'           => 'select',
            'title'          => esc_html__('Sidebar Style', 'cascara'),
            'options'        => array(
              'normal'       => esc_html__('Normal', 'cascara'),
              'bar-sticky'   => esc_html__('Sticky', 'cascara'),
              'bar-float'    => esc_html__('Floating', 'cascara'),
            ),
            'default_option' => 'Select Sidebar Style',
            'dependency'     => array('single_sidebar_position', '!=', 'sidebar-hide'),
          ),
          // End fields

        )
      ),

    ),
  );

  // ------------------------------
  // Extra Pages
  // ------------------------------
  $options[]   = array(
    'name'     => 'theme_extra_pages',
    'title'    => esc_html__('Extra Pages', 'cascara'),
    'icon'     => 'fa fa-clone',
    'sections' => array(

      // error 404 page
      array(
        'name'     => 'error_page_section',
        'title'    => esc_html__('404 Page', 'cascara'),
        'icon'     => 'fa fa-exclamation-triangle',
        'fields'   => array(

          // Start 404 Page
          array(
            'id'    => 'error_heading',
            'type'  => 'text',
            'title' => esc_html__('404 Page Heading', 'cascara'),
            'info'  => esc_html__('Enter 404 page heading.', 'cascara'),
          ),
          array(
            'id'    => 'error_sub_heading',
            'type'  => 'text',
            'title' => esc_html__('404 Page Sub Heading', 'cascara'),
            'info'  => esc_html__('Enter 404 page sub heading.', 'cascara'),
          ),
          array(
            'id'    => 'error_page_content',
            'type'  => 'textarea',
            'title' => esc_html__('404 Page Content', 'cascara'),
            'info'  => esc_html__('Enter 404 page content.', 'cascara'),
            'shortcode' => true,
          ),
          array(
            'id'    => 'error_btn_text',
            'type'  => 'text',
            'title' => esc_html__('Button Text', 'cascara'),
            'info'  => esc_html__('Enter BACK TO HOME button text. If you want to change it.', 'cascara'),
          ),
          array(
            'id'    => 'promotion_image_404',
            'type'  => 'image',
            'title' => esc_html__('Promotion Banner Image', 'cascara'),
            'info'  => esc_html__('Upload your promotion image here (It will display in the top of blog global pages)', 'cascara'),
            'add_title' => esc_html__('Add Image', 'cascara'),
          ),
          array(
            'id'      => 'promotion_image_link_404',
            'type'    => 'text',
            'title'   => esc_html__('Promotion Image Link', 'cascara'),
          ),
          // End 404 Page

        ) // end: fields
      ), // end: fields section

      // maintenance mode page
      array(
        'name'     => 'maintenance_mode_section',
        'title'    => esc_html__('Maintenance Mode', 'cascara'),
        'icon'     => 'fa fa-hourglass-half',
        'fields'   => array(

          // Start Maintenance Mode
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('If you turn this ON : Only Logged in users will see your pages. All other visiters will see, selected page of : <strong>Maintenance Mode Page</strong>', 'cascara')
          ),
          array(
            'id'             => 'enable_maintenance_mode',
            'type'           => 'switcher',
            'title'          => esc_html__('Maintenance Mode', 'cascara'),
            'default'        => false,
          ),
          array(
            'id'             => 'maintenance_mode_page',
            'type'           => 'select',
            'title'          => esc_html__('Maintenance Mode Page', 'cascara'),
            'options'        => 'pages',
            'default_option' => esc_html__('Select a page', 'cascara'),
            'dependency'   => array( 'enable_maintenance_mode', '==', 'true' ),
          ),
          array(
            'id'             => 'maintenance_mode_bg',
            'type'           => 'background',
            'title'          => esc_html__('Page Background', 'cascara'),
            'dependency'   => array( 'enable_maintenance_mode', '==', 'true' ),
          ),
          // End Maintenance Mode

        ) // end: fields
      ), // end: fields section

    )
  );

  // ------------------------------
  // Advanced
  // ------------------------------
  $options[] = array(
    'name'   => 'theme_advanced',
    'title'  => esc_html__('Advanced', 'cascara'),
    'icon'   => 'fa fa-cog'
  );

  // ------------------------------
  // Misc Section
  // ------------------------------
  $options[]   = array(
    'name'     => 'misc_section',
    'title'    => esc_html__('Misc', 'cascara'),
    'icon'     => 'fa fa-recycle',
    'sections' => array(

      // custom sidebar section
      array(
        'name'     => 'custom_sidebar_section',
        'title'    => esc_html__('Custom Sidebar', 'cascara'),
        'icon'     => 'fa fa-reorder',
        'fields'   => array(

          // start fields
          array(
            'id'              => 'custom_sidebar',
            'title'           => esc_html__('Sidebars', 'cascara'),
            'desc'            => esc_html__('Go to Appearance -> Widgets after create sidebars', 'cascara'),
            'type'            => 'group',
            'fields'          => array(
              array(
                'id'          => 'sidebar_name',
                'type'        => 'text',
                'title'       => esc_html__('Sidebar Name', 'cascara'),
              ),
              array(
                'id'          => 'sidebar_desc',
                'type'        => 'text',
                'title'       => esc_html__('Custom Description', 'cascara'),
              )
            ),
            'accordion'       => true,
            'button_title'    => esc_html__('Add New Sidebar', 'cascara'),
            'accordion_title' => esc_html__('New Sidebar', 'cascara'),
            'default'             => array(
              array(
                'sidebar_name'          => 'Recent Posts',
                'sidebar_desc'        => 'Shows The Recent Posts',
              ),
              array(
                'sidebar_name'          => 'Recent Comments',
                'sidebar_desc'        => 'Shows The Recent Comments',
              ),
              array(
                'sidebar_name'          => 'Post Categories',
                'sidebar_desc'        => 'Shows The Post Categories',
              ),
            )
          ),
          // end fields

        )
      ),
      // custom sidebar section

      // Custom CSS/JS
      array(
        'name'        => 'custom_css_js_section',
        'title'       => esc_html__('Custom Codes', 'cascara'),
        'icon'        => 'fa fa-code',

        // begin: fields
        'fields'      => array(

          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Custom JS', 'cascara')
          ),
          array(
            'id'             => 'theme_custom_js',
            'type'           => 'textarea',
            'attributes' => array(
              'rows'     => 10,
              'placeholder'     => esc_html__('Enter your JS code here...', 'cascara'),
            ),
          ),
          // End Custom CSS/JS

        ) // end: fields
      ),

      // Translation
      array(
        'name'        => 'theme_translation_section',
        'title'       => esc_html__('Translation', 'cascara'),
        'icon'        => 'fa fa-language',

        // begin: fields
        'fields'      => array(

          // Start Translation
          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Common Texts', 'cascara')
          ),
          array(
            'id'          => 'read_more_text',
            'type'        => 'text',
            'title'       => esc_html__('Read More Text', 'cascara'),
          ),
          array(
            'id'          => 'post_comment_text',
            'type'        => 'text',
            'title'       => esc_html__('Post Comment Text [Submit Button]', 'cascara'),
          ),

          array(
            'type'    => 'notice',
            'class'   => 'info cs-vt-heading',
            'content' => esc_html__('Pagination', 'cascara')
          ),
          array(
            'id'          => 'older_post',
            'type'        => 'text',
            'title'       => esc_html__('Older Posts Text', 'cascara'),
          ),
          array(
            'id'          => 'newer_post',
            'type'        => 'text',
            'title'       => esc_html__('Newer Posts Text', 'cascara'),
          ),

          // End Translation

        ) // end: fields
      ),

    ),
  );

  // ------------------------------
  // backup                       -
  // ------------------------------
  $options[]   = array(
    'name'     => 'backup_section',
    'title'    => esc_html__('Backup', 'cascara'),
    'icon'     => 'fa fa-shield',
    'fields'   => array(

      array(
        'type'    => 'notice',
        'class'   => 'warning',
        'content' => esc_html__('You can save your current options. Download a Backup and Import.', 'cascara'),
      ),

      array(
        'type'    => 'backup',
      ),

    )
  );

  return $options;

}
add_filter( 'cs_framework_options', 'cascara_vt_options' );
